# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/instances/instances.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/instances/instances.proto',
  package='yamcs.protobuf.instances',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\016InstancesProtoP\001',
  serialized_pb=b'\n(yamcs/protobuf/instances/instances.proto\x12\x18yamcs.protobuf.instances\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\"\xf7\x05\n\rYamcsInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0fmissionDatabase\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.mdb.MissionDatabase\x12\x41\n\nprocessors\x18\x04 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\x12\x44\n\x05state\x18\x0b \x01(\x0e\x32\x35.yamcs.protobuf.instances.YamcsInstance.InstanceState\x12\x14\n\x0c\x66\x61ilureCause\x18\t \x01(\t\x12/\n\x0bmissionTime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x0c \x03(\x0b\x32\x33.yamcs.protobuf.instances.YamcsInstance.LabelsEntry\x12\x14\n\x0c\x63\x61pabilities\x18\r \x03(\t\x12\x10\n\x08template\x18\x0e \x01(\t\x12O\n\x0ctemplateArgs\x18\x0f \x03(\x0b\x32\x39.yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry\x12\x19\n\x11templateAvailable\x18\x10 \x01(\x08\x12\x17\n\x0ftemplateChanged\x18\x11 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\rInstanceState\x12\x0b\n\x07OFFLINE\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0f\n\x0bINITIALIZED\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\"t\n\x10InstanceTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\tvariables\x18\x02 \x03(\x0b\x32*.yamcs.protobuf.instances.TemplateVariable\"\x7f\n\x10TemplateVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04help\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\x12\x0f\n\x07initial\x18\x07 \x01(\tB&\n\x12org.yamcs.protobufB\x0eInstancesProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,])



_YAMCSINSTANCE_INSTANCESTATE = _descriptor.EnumDescriptor(
  name='InstanceState',
  full_name='yamcs.protobuf.instances.YamcsInstance.InstanceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=831,
  serialized_end=947,
)
_sym_db.RegisterEnumDescriptor(_YAMCSINSTANCE_INSTANCESTATE)


_YAMCSINSTANCE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=776,
)

_YAMCSINSTANCE_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=829,
)

_YAMCSINSTANCE = _descriptor.Descriptor(
  name='YamcsInstance',
  full_name='yamcs.protobuf.instances.YamcsInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.YamcsInstance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionDatabase', full_name='yamcs.protobuf.instances.YamcsInstance.missionDatabase', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processors', full_name='yamcs.protobuf.instances.YamcsInstance.processors', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.instances.YamcsInstance.state', index=3,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureCause', full_name='yamcs.protobuf.instances.YamcsInstance.failureCause', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionTime', full_name='yamcs.protobuf.instances.YamcsInstance.missionTime', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.YamcsInstance.labels', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='yamcs.protobuf.instances.YamcsInstance.capabilities', index=7,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.YamcsInstance.template', index=8,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.YamcsInstance.templateArgs', index=9,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateAvailable', full_name='yamcs.protobuf.instances.YamcsInstance.templateAvailable', index=10,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateChanged', full_name='yamcs.protobuf.instances.YamcsInstance.templateChanged', index=11,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_YAMCSINSTANCE_LABELSENTRY, _YAMCSINSTANCE_TEMPLATEARGSENTRY, ],
  enum_types=[
    _YAMCSINSTANCE_INSTANCESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=947,
)


_INSTANCETEMPLATE = _descriptor.Descriptor(
  name='InstanceTemplate',
  full_name='yamcs.protobuf.instances.InstanceTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.InstanceTemplate.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.instances.InstanceTemplate.description', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variables', full_name='yamcs.protobuf.instances.InstanceTemplate.variables', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1065,
)


_TEMPLATEVARIABLE = _descriptor.Descriptor(
  name='TemplateVariable',
  full_name='yamcs.protobuf.instances.TemplateVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.TemplateVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.instances.TemplateVariable.label', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.instances.TemplateVariable.type', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='yamcs.protobuf.instances.TemplateVariable.help', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='yamcs.protobuf.instances.TemplateVariable.required', index=4,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='choices', full_name='yamcs.protobuf.instances.TemplateVariable.choices', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial', full_name='yamcs.protobuf.instances.TemplateVariable.initial', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1194,
)

_YAMCSINSTANCE_LABELSENTRY.containing_type = _YAMCSINSTANCE
_YAMCSINSTANCE_TEMPLATEARGSENTRY.containing_type = _YAMCSINSTANCE
_YAMCSINSTANCE.fields_by_name['missionDatabase'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._MISSIONDATABASE
_YAMCSINSTANCE.fields_by_name['processors'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_YAMCSINSTANCE.fields_by_name['state'].enum_type = _YAMCSINSTANCE_INSTANCESTATE
_YAMCSINSTANCE.fields_by_name['missionTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_YAMCSINSTANCE.fields_by_name['labels'].message_type = _YAMCSINSTANCE_LABELSENTRY
_YAMCSINSTANCE.fields_by_name['templateArgs'].message_type = _YAMCSINSTANCE_TEMPLATEARGSENTRY
_YAMCSINSTANCE_INSTANCESTATE.containing_type = _YAMCSINSTANCE
_INSTANCETEMPLATE.fields_by_name['variables'].message_type = _TEMPLATEVARIABLE
DESCRIPTOR.message_types_by_name['YamcsInstance'] = _YAMCSINSTANCE
DESCRIPTOR.message_types_by_name['InstanceTemplate'] = _INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['TemplateVariable'] = _TEMPLATEVARIABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YamcsInstance = _reflection.GeneratedProtocolMessageType('YamcsInstance', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _YAMCSINSTANCE_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance.LabelsEntry)
    })
  ,

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _YAMCSINSTANCE_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry)
    })
  ,
  'DESCRIPTOR' : _YAMCSINSTANCE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance)
  })
_sym_db.RegisterMessage(YamcsInstance)
_sym_db.RegisterMessage(YamcsInstance.LabelsEntry)
_sym_db.RegisterMessage(YamcsInstance.TemplateArgsEntry)

InstanceTemplate = _reflection.GeneratedProtocolMessageType('InstanceTemplate', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCETEMPLATE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.InstanceTemplate)
  })
_sym_db.RegisterMessage(InstanceTemplate)

TemplateVariable = _reflection.GeneratedProtocolMessageType('TemplateVariable', (_message.Message,), {
  'DESCRIPTOR' : _TEMPLATEVARIABLE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.TemplateVariable)
  })
_sym_db.RegisterMessage(TemplateVariable)


DESCRIPTOR._options = None
_YAMCSINSTANCE_LABELSENTRY._options = None
_YAMCSINSTANCE_TEMPLATEARGSENTRY._options = None
# @@protoc_insertion_point(module_scope)
