# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/plists/plists.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/plists/plists.proto',
  package='yamcs.protobuf.plists',
  syntax='proto2',
  serialized_options=b'\n\031org.yamcs.protobuf.plistsB\023ParameterListsProtoP\001',
  serialized_pb=b'\n\"yamcs/protobuf/plists/plists.proto\x12\x15yamcs.protobuf.plists\x1a\x1cyamcs/protobuf/mdb/mdb.proto\"\x86\x01\n\x11ParameterListInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08patterns\x18\x04 \x03(\t\x12\x30\n\x05match\x18\x05 \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfoB2\n\x19org.yamcs.protobuf.plistsB\x13ParameterListsProtoP\x01'
  ,
  dependencies=[yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,])




_PARAMETERLISTINFO = _descriptor.Descriptor(
  name='ParameterListInfo',
  full_name='yamcs.protobuf.plists.ParameterListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.plists.ParameterListInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.plists.ParameterListInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.plists.ParameterListInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='yamcs.protobuf.plists.ParameterListInfo.patterns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match', full_name='yamcs.protobuf.plists.ParameterListInfo.match', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=226,
)

_PARAMETERLISTINFO.fields_by_name['match'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._PARAMETERINFO
DESCRIPTOR.message_types_by_name['ParameterListInfo'] = _PARAMETERLISTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParameterListInfo = _reflection.GeneratedProtocolMessageType('ParameterListInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERLISTINFO,
  '__module__' : 'yamcs.protobuf.plists.plists_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.ParameterListInfo)
  })
_sym_db.RegisterMessage(ParameterListInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
