# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/api/websocket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from yamcs.api import exception_pb2 as yamcs_dot_api_dot_exception__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/api/websocket.proto',
  package='yamcs.api',
  syntax='proto3',
  serialized_options=b'\n\022org.yamcs.protobufB\016WebSocketProtoP\001',
  serialized_pb=b'\n\x19yamcs/api/websocket.proto\x12\tyamcs.api\x1a\x19google/protobuf/any.proto\x1a\x19yamcs/api/exception.proto\"\x91\x01\n\rClientMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12%\n\x07options\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63\x61ll\x18\x04 \x01(\x05\x12\x1c\n\x10maxDroppedWrites\x18\x05 \x01(\x05\x42\x02\x18\x01\x12\x13\n\x0blowPriority\x18\x06 \x01(\x08\"\\\n\rServerMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04\x63\x61ll\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\"\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x1d\n\rCancelOptions\x12\x0c\n\x04\x63\x61ll\x18\x01 \x01(\x05\"I\n\x05Reply\x12\x10\n\x08reply_to\x18\x01 \x01(\x05\x12.\n\texception\x18\x02 \x01(\x0b\x32\x1b.yamcs.api.ExceptionMessage\"\x80\x01\n\x05State\x12(\n\x05\x63\x61lls\x18\x01 \x03(\x0b\x32\x19.yamcs.api.State.CallInfo\x1aM\n\x08\x43\x61llInfo\x12\x0c\n\x04\x63\x61ll\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12%\n\x07options\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB&\n\x12org.yamcs.protobufB\x0eWebSocketProtoP\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,yamcs_dot_api_dot_exception__pb2.DESCRIPTOR,])




_CLIENTMESSAGE = _descriptor.Descriptor(
  name='ClientMessage',
  full_name='yamcs.api.ClientMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.ClientMessage.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.api.ClientMessage.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.api.ClientMessage.id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.ClientMessage.call', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxDroppedWrites', full_name='yamcs.api.ClientMessage.maxDroppedWrites', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowPriority', full_name='yamcs.api.ClientMessage.lowPriority', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=240,
)


_SERVERMESSAGE = _descriptor.Descriptor(
  name='ServerMessage',
  full_name='yamcs.api.ServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.ServerMessage.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.ServerMessage.call', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.api.ServerMessage.seq', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.api.ServerMessage.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=334,
)


_CANCELOPTIONS = _descriptor.Descriptor(
  name='CancelOptions',
  full_name='yamcs.api.CancelOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.CancelOptions.call', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=365,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='yamcs.api.Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='yamcs.api.Reply.reply_to', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='yamcs.api.Reply.exception', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=440,
)


_STATE_CALLINFO = _descriptor.Descriptor(
  name='CallInfo',
  full_name='yamcs.api.State.CallInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.State.CallInfo.call', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.State.CallInfo.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.api.State.CallInfo.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=571,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='yamcs.api.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calls', full_name='yamcs.api.State.calls', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_CALLINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=571,
)

_CLIENTMESSAGE.fields_by_name['options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SERVERMESSAGE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REPLY.fields_by_name['exception'].message_type = yamcs_dot_api_dot_exception__pb2._EXCEPTIONMESSAGE
_STATE_CALLINFO.fields_by_name['options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE_CALLINFO.containing_type = _STATE
_STATE.fields_by_name['calls'].message_type = _STATE_CALLINFO
DESCRIPTOR.message_types_by_name['ClientMessage'] = _CLIENTMESSAGE
DESCRIPTOR.message_types_by_name['ServerMessage'] = _SERVERMESSAGE
DESCRIPTOR.message_types_by_name['CancelOptions'] = _CANCELOPTIONS
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
DESCRIPTOR.message_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientMessage = _reflection.GeneratedProtocolMessageType('ClientMessage', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTMESSAGE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.ClientMessage)
  })
_sym_db.RegisterMessage(ClientMessage)

ServerMessage = _reflection.GeneratedProtocolMessageType('ServerMessage', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMESSAGE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.ServerMessage)
  })
_sym_db.RegisterMessage(ServerMessage)

CancelOptions = _reflection.GeneratedProtocolMessageType('CancelOptions', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPTIONS,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.CancelOptions)
  })
_sym_db.RegisterMessage(CancelOptions)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.Reply)
  })
_sym_db.RegisterMessage(Reply)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'CallInfo' : _reflection.GeneratedProtocolMessageType('CallInfo', (_message.Message,), {
    'DESCRIPTOR' : _STATE_CALLINFO,
    '__module__' : 'yamcs.api.websocket_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.api.State.CallInfo)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.CallInfo)


DESCRIPTOR._options = None
_CLIENTMESSAGE.fields_by_name['maxDroppedWrites']._options = None
# @@protoc_insertion_point(module_scope)
