# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/services/services_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.services import services_pb2 as yamcs_dot_protobuf_dot_services_dot_services__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/services/services_service.proto',
  package='yamcs.protobuf.services',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024ServicesServiceProtoP\001',
  serialized_pb=b'\n.yamcs/protobuf/services/services_service.proto\x12\x17yamcs.protobuf.services\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a&yamcs/protobuf/services/services.proto\"\'\n\x13ListServicesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"3\n\x11GetServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x13StartServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x12StopServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x14ListServicesResponse\x12\x36\n\x08services\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.services.ServiceInfo2\xa7\x04\n\x0bServicesApi\x12\x8b\x01\n\x0cListServices\x12,.yamcs.protobuf.services.ListServicesRequest\x1a-.yamcs.protobuf.services.ListServicesResponse\"\x1e\x8a\x92\x03\x1a\n\x18/api/services/{instance}\x12\x85\x01\n\nGetService\x12*.yamcs.protobuf.services.GetServiceRequest\x1a$.yamcs.protobuf.services.ServiceInfo\"%\x8a\x92\x03!\n\x1f/api/services/{instance}/{name}\x12\x81\x01\n\x0cStartService\x12,.yamcs.protobuf.services.StartServiceRequest\x1a\x16.google.protobuf.Empty\"+\x8a\x92\x03\'\x1a%/api/services/{instance}/{name}:start\x12~\n\x0bStopService\x12+.yamcs.protobuf.services.StopServiceRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\x1a$/api/services/{instance}/{name}:stopB,\n\x12org.yamcs.protobufB\x14ServicesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_services_dot_services__pb2.DESCRIPTOR,])




_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='yamcs.protobuf.services.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.ListServicesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=212,
)


_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='yamcs.protobuf.services.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.GetServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.GetServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=265,
)


_STARTSERVICEREQUEST = _descriptor.Descriptor(
  name='StartServiceRequest',
  full_name='yamcs.protobuf.services.StartServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.StartServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.StartServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=320,
)


_STOPSERVICEREQUEST = _descriptor.Descriptor(
  name='StopServiceRequest',
  full_name='yamcs.protobuf.services.StopServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.StopServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.StopServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=374,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='yamcs.protobuf.services.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.services.ListServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=454,
)

_LISTSERVICESRESPONSE.fields_by_name['services'].message_type = yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICEINFO
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StartServiceRequest'] = _STARTSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StopServiceRequest'] = _STOPSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)

StartServiceRequest = _reflection.GeneratedProtocolMessageType('StartServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.StartServiceRequest)
  })
_sym_db.RegisterMessage(StartServiceRequest)

StopServiceRequest = _reflection.GeneratedProtocolMessageType('StopServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.StopServiceRequest)
  })
_sym_db.RegisterMessage(StopServiceRequest)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)


DESCRIPTOR._options = None

_SERVICESAPI = _descriptor.ServiceDescriptor(
  name='ServicesApi',
  full_name='yamcs.protobuf.services.ServicesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=457,
  serialized_end=1008,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListServices',
    full_name='yamcs.protobuf.services.ServicesApi.ListServices',
    index=0,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=b'\212\222\003\032\n\030/api/services/{instance}',
  ),
  _descriptor.MethodDescriptor(
    name='GetService',
    full_name='yamcs.protobuf.services.ServicesApi.GetService',
    index=1,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICEINFO,
    serialized_options=b'\212\222\003!\n\037/api/services/{instance}/{name}',
  ),
  _descriptor.MethodDescriptor(
    name='StartService',
    full_name='yamcs.protobuf.services.ServicesApi.StartService',
    index=2,
    containing_service=None,
    input_type=_STARTSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\'\032%/api/services/{instance}/{name}:start',
  ),
  _descriptor.MethodDescriptor(
    name='StopService',
    full_name='yamcs.protobuf.services.ServicesApi.StopService',
    index=3,
    containing_service=None,
    input_type=_STOPSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003&\032$/api/services/{instance}/{name}:stop',
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICESAPI)

DESCRIPTOR.services_by_name['ServicesApi'] = _SERVICESAPI

# @@protoc_insertion_point(module_scope)
