# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/yamcsManagement/yamcsManagement.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.services import services_pb2 as yamcs_dot_protobuf_dot_services_dot_services__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/yamcsManagement/yamcsManagement.proto',
  package='yamcs.protobuf.yamcsManagement',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024YamcsManagementProtoP\001',
  serialized_pb=b'\n4yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x12\x1eyamcs.protobuf.yamcsManagement\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ayamcs/protobuf/yamcs.proto\x1a&yamcs/protobuf/services/services.proto\"\xb6\x04\n\rProcessorInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12\x0f\n\x07\x63reator\x18\x05 \x01(\t\x12\x11\n\thasAlarms\x18\x06 \x01(\x08\x12\x15\n\rhasCommanding\x18\x07 \x01(\x08\x12\x34\n\x05state\x18\x08 \x01(\x0e\x32%.yamcs.protobuf.services.ServiceState\x12\x34\n\rreplayRequest\x18\t \x01(\x0b\x32\x1d.yamcs.protobuf.ReplayRequest\x12=\n\x0breplayState\x18\n \x01(\x0e\x32(.yamcs.protobuf.ReplayStatus.ReplayState\x12\x36\n\x08services\x18\x10 \x03(\x0b\x32$.yamcs.protobuf.services.ServiceInfo\x12\x12\n\npersistent\x18\x11 \x01(\x08\x12(\n\x04time\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06replay\x18\x13 \x01(\x08\x12\x1d\n\x15\x63heckCommandClearance\x18\x14 \x01(\x08\x12\x11\n\tprotected\x18\x15 \x01(\x08\x12K\n\x0f\x61\x63knowledgments\x18\x16 \x03(\x0b\x32\x32.yamcs.protobuf.yamcsManagement.AcknowledgmentInfo\"7\n\x12\x41\x63knowledgmentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x98\x02\n\x0cTmStatistics\x12\x12\n\npacketName\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\t \x01(\t\x12\x17\n\x0freceivedPackets\x18\x02 \x01(\x03\x12 \n\x18subscribedParameterCount\x18\x06 \x01(\x05\x12\x30\n\x0clastReceived\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elastPacketTime\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\npacketRate\x18\x0c \x01(\x03\x12\x10\n\x08\x64\x61taRate\x18\r \x01(\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"\xb3\x01\n\nStatistics\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12=\n\x07tmstats\x18\x03 \x03(\x0b\x32,.yamcs.protobuf.yamcsManagement.TmStatistics\x12/\n\x0blastUpdated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\x8b\x02\n\x1aProcessorManagementRequest\x12W\n\toperation\x18\x01 \x01(\x0e\x32\x44.yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x19\n\npersistent\x18\x07 \x01(\x08:\x05\x66\x61lse\";\n\tOperation\x12\x14\n\x10\x43REATE_PROCESSOR\x10\x00\x12\x18\n\x14\x43ONNECT_TO_PROCESSOR\x10\x01\"\x85\x02\n\x10ProcessorRequest\x12M\n\toperation\x18\x01 \x01(\x0e\x32:.yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08seekTime\x18\x04 \x01(\x03\x12\x30\n\x0breplaySpeed\x18\x05 \x01(\x0b\x32\x1b.yamcs.protobuf.ReplaySpeed\">\n\tOperation\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x12\x08\n\x04SEEK\x10\x04\x12\x10\n\x0c\x43HANGE_SPEED\x10\x05\"\x9d\x01\n\x0bStreamEvent\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.yamcs.protobuf.yamcsManagement.StreamEvent.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdataCount\x18\x03 \x01(\x03\"-\n\x04Type\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x42,\n\x12org.yamcs.protobufB\x14YamcsManagementProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_services_dot_services__pb2.DESCRIPTOR,])



_PROCESSORMANAGEMENTREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE_PROCESSOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT_TO_PROCESSOR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1489,
  serialized_end=1548,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORMANAGEMENTREQUEST_OPERATION)

_PROCESSORREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=0, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=1, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEEK', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_SPEED', index=3, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1750,
  serialized_end=1812,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORREQUEST_OPERATION)

_STREAMEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.yamcsManagement.StreamEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1927,
  serialized_end=1972,
)
_sym_db.RegisterEnumDescriptor(_STREAMEVENT_TYPE)


_PROCESSORINFO = _descriptor.Descriptor(
  name='ProcessorInfo',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.creator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasAlarms', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasAlarms', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasCommanding', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasCommanding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.state', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayRequest', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayRequest', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayState', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayState', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.services', index=10,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.persistent', index=11,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.time', index=12,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replay', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replay', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checkCommandClearance', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.checkCommandClearance', index=14,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protected', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.protected', index=15,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledgments', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.acknowledgments', index=16,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=756,
)


_ACKNOWLEDGMENTINFO = _descriptor.Descriptor(
  name='AcknowledgmentInfo',
  full_name='yamcs.protobuf.yamcsManagement.AcknowledgmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.AcknowledgmentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.yamcsManagement.AcknowledgmentInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=813,
)


_TMSTATISTICS = _descriptor.Descriptor(
  name='TmStatistics',
  full_name='yamcs.protobuf.yamcsManagement.TmStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packetName', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.packetName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.qualifiedName', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receivedPackets', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.receivedPackets', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribedParameterCount', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.subscribedParameterCount', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastReceived', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastReceived', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastPacketTime', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastPacketTime', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetRate', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.packetRate', index=6,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataRate', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.dataRate', index=7,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=1096,
)


_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='yamcs.protobuf.yamcsManagement.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.Statistics.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.yamcsManagement.Statistics.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmstats', full_name='yamcs.protobuf.yamcsManagement.Statistics.tmstats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='yamcs.protobuf.yamcsManagement.Statistics.lastUpdated', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1278,
)


_PROCESSORMANAGEMENTREQUEST = _descriptor.Descriptor(
  name='ProcessorManagementRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.config', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.persistent', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORMANAGEMENTREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1548,
)


_PROCESSORREQUEST = _descriptor.Descriptor(
  name='ProcessorRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seekTime', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.seekTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replaySpeed', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.replaySpeed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1551,
  serialized_end=1812,
)


_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='yamcs.protobuf.yamcsManagement.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataCount', full_name='yamcs.protobuf.yamcsManagement.StreamEvent.dataCount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1972,
)

_PROCESSORINFO.fields_by_name['state'].enum_type = yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICESTATE
_PROCESSORINFO.fields_by_name['replayRequest'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYREQUEST
_PROCESSORINFO.fields_by_name['replayState'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSTATUS_REPLAYSTATE
_PROCESSORINFO.fields_by_name['services'].message_type = yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICEINFO
_PROCESSORINFO.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROCESSORINFO.fields_by_name['acknowledgments'].message_type = _ACKNOWLEDGMENTINFO
_TMSTATISTICS.fields_by_name['lastReceived'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TMSTATISTICS.fields_by_name['lastPacketTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATISTICS.fields_by_name['tmstats'].message_type = _TMSTATISTICS
_STATISTICS.fields_by_name['lastUpdated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROCESSORMANAGEMENTREQUEST.fields_by_name['operation'].enum_type = _PROCESSORMANAGEMENTREQUEST_OPERATION
_PROCESSORMANAGEMENTREQUEST_OPERATION.containing_type = _PROCESSORMANAGEMENTREQUEST
_PROCESSORREQUEST.fields_by_name['operation'].enum_type = _PROCESSORREQUEST_OPERATION
_PROCESSORREQUEST.fields_by_name['replaySpeed'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSPEED
_PROCESSORREQUEST_OPERATION.containing_type = _PROCESSORREQUEST
_STREAMEVENT.fields_by_name['type'].enum_type = _STREAMEVENT_TYPE
_STREAMEVENT_TYPE.containing_type = _STREAMEVENT
DESCRIPTOR.message_types_by_name['ProcessorInfo'] = _PROCESSORINFO
DESCRIPTOR.message_types_by_name['AcknowledgmentInfo'] = _ACKNOWLEDGMENTINFO
DESCRIPTOR.message_types_by_name['TmStatistics'] = _TMSTATISTICS
DESCRIPTOR.message_types_by_name['Statistics'] = _STATISTICS
DESCRIPTOR.message_types_by_name['ProcessorManagementRequest'] = _PROCESSORMANAGEMENTREQUEST
DESCRIPTOR.message_types_by_name['ProcessorRequest'] = _PROCESSORREQUEST
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessorInfo = _reflection.GeneratedProtocolMessageType('ProcessorInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorInfo)
  })
_sym_db.RegisterMessage(ProcessorInfo)

AcknowledgmentInfo = _reflection.GeneratedProtocolMessageType('AcknowledgmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACKNOWLEDGMENTINFO,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.AcknowledgmentInfo)
  })
_sym_db.RegisterMessage(AcknowledgmentInfo)

TmStatistics = _reflection.GeneratedProtocolMessageType('TmStatistics', (_message.Message,), {
  'DESCRIPTOR' : _TMSTATISTICS,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.TmStatistics)
  })
_sym_db.RegisterMessage(TmStatistics)

Statistics = _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICS,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.Statistics)
  })
_sym_db.RegisterMessage(Statistics)

ProcessorManagementRequest = _reflection.GeneratedProtocolMessageType('ProcessorManagementRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORMANAGEMENTREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorManagementRequest)
  })
_sym_db.RegisterMessage(ProcessorManagementRequest)

ProcessorRequest = _reflection.GeneratedProtocolMessageType('ProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorRequest)
  })
_sym_db.RegisterMessage(ProcessorRequest)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENT,
  '__module__' : 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.StreamEvent)
  })
_sym_db.RegisterMessage(StreamEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
