# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/actions/actions.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf.config import config_pb2 as yamcs_dot_protobuf_dot_config_dot_config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/actions/actions.proto',
  package='yamcs.protobuf.actions',
  syntax='proto2',
  serialized_options=b'\n\032org.yamcs.protobuf.actionsB\014ActionsProtoP\001',
  serialized_pb=b'\n$yamcs/protobuf/actions/actions.proto\x12\x16yamcs.protobuf.actions\x1a\"yamcs/protobuf/config/config.proto\"\x87\x01\n\nActionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\r\n\x05style\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0f\n\x07\x63hecked\x18\x05 \x01(\x08\x12-\n\x04spec\x18\x06 \x01(\x0b\x32\x1f.yamcs.protobuf.config.SpecInfoB,\n\x1aorg.yamcs.protobuf.actionsB\x0c\x41\x63tionsProtoP\x01'
  ,
  dependencies=[yamcs_dot_protobuf_dot_config_dot_config__pb2.DESCRIPTOR,])




_ACTIONINFO = _descriptor.Descriptor(
  name='ActionInfo',
  full_name='yamcs.protobuf.actions.ActionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.actions.ActionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.actions.ActionInfo.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='yamcs.protobuf.actions.ActionInfo.style', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yamcs.protobuf.actions.ActionInfo.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checked', full_name='yamcs.protobuf.actions.ActionInfo.checked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.actions.ActionInfo.spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=236,
)

_ACTIONINFO.fields_by_name['spec'].message_type = yamcs_dot_protobuf_dot_config_dot_config__pb2._SPECINFO
DESCRIPTOR.message_types_by_name['ActionInfo'] = _ACTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActionInfo = _reflection.GeneratedProtocolMessageType('ActionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONINFO,
  '__module__' : 'yamcs.protobuf.actions.actions_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.actions.ActionInfo)
  })
_sym_db.RegisterMessage(ActionInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
