# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/mdb/mdb.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/mdb/mdb.proto',
  package='yamcs.protobuf.mdb',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobuf',
  serialized_pb=b'\n\x1cyamcs/protobuf/mdb/mdb.proto\x12\x12yamcs.protobuf.mdb\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xb7\x02\n\x0fMissionDatabase\x12\x12\n\nconfigName\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12<\n\x0bspaceSystem\x18\x04 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfoB\x02\x18\x01\x12\x39\n\x0cspaceSystems\x18\x0b \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x16\n\x0eparameterCount\x18\x06 \x01(\x05\x12\x16\n\x0e\x63ontainerCount\x18\x07 \x01(\x05\x12\x14\n\x0c\x63ommandCount\x18\x08 \x01(\x05\x12\x16\n\x0e\x61lgorithmCount\x18\t \x01(\x05\x12\x1a\n\x12parameterTypeCount\x18\n \x01(\x05\"M\n\x0bHistoryInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\"\x18\n\x08UnitInfo\x12\x0c\n\x04unit\x18\x01 \x01(\t\"\x97\x01\n\nAlarmRange\x12\x31\n\x05level\x18\x01 \x01(\x0e\x32\".yamcs.protobuf.mdb.AlarmLevelType\x12\x14\n\x0cminInclusive\x18\x02 \x01(\x01\x12\x14\n\x0cmaxInclusive\x18\x03 \x01(\x01\x12\x14\n\x0cminExclusive\x18\x04 \x01(\x01\x12\x14\n\x0cmaxExclusive\x18\x05 \x01(\x01\"T\n\x10\x45numerationAlarm\x12\x31\n\x05level\x18\x01 \x01(\x0e\x32\".yamcs.protobuf.mdb.AlarmLevelType\x12\r\n\x05label\x18\x03 \x01(\t\"\xa0\x02\n\tAlarmInfo\x12\x15\n\rminViolations\x18\x01 \x01(\x05\x12<\n\x10staticAlarmRange\x18\x02 \x03(\x0b\x32\x1e.yamcs.protobuf.mdb.AlarmRangeB\x02\x18\x01\x12\x39\n\x11staticAlarmRanges\x18\x04 \x03(\x0b\x32\x1e.yamcs.protobuf.mdb.AlarmRange\x12\x42\n\x10\x65numerationAlarm\x18\x03 \x03(\x0b\x32$.yamcs.protobuf.mdb.EnumerationAlarmB\x02\x18\x01\x12?\n\x11\x65numerationAlarms\x18\x05 \x03(\x0b\x32$.yamcs.protobuf.mdb.EnumerationAlarm\"\x89\x01\n\x10\x43ontextAlarmInfo\x12\x36\n\ncomparison\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12,\n\x05\x61larm\x18\x02 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\"\x9c\x03\n\x10\x44\x61taEncodingInfo\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).yamcs.protobuf.mdb.DataEncodingInfo.Type\x12\x14\n\x0clittleEndian\x18\x02 \x01(\x08\x12\x12\n\nsizeInBits\x18\x03 \x01(\x05\x12\x10\n\x08\x65ncoding\x18\x04 \x01(\t\x12=\n\x11\x64\x65\x66\x61ultCalibrator\x18\x06 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12H\n\x11\x63ontextCalibrator\x18\x07 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfoB\x02\x18\x01\x12\x45\n\x12\x63ontextCalibrators\x18\x08 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfo\"C\n\x04Type\x12\n\n\x06\x42INARY\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\n\n\x06STRING\x10\x04\"\x98\x01\n\x15\x43ontextCalibratorInfo\x12\x36\n\ncomparison\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12\x36\n\ncalibrator\x18\x02 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\"\xf8\x02\n\x0e\x43\x61libratorInfo\x12J\n\x14polynomialCalibrator\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.mdb.PolynomialCalibratorInfo\x12\x42\n\x10splineCalibrator\x18\x03 \x01(\x0b\x32(.yamcs.protobuf.mdb.SplineCalibratorInfo\x12R\n\x18javaExpressionCalibrator\x18\x04 \x01(\x0b\x32\x30.yamcs.protobuf.mdb.JavaExpressionCalibratorInfo\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.yamcs.protobuf.mdb.CalibratorInfo.Type\"K\n\x04Type\x12\x0e\n\nPOLYNOMIAL\x10\x00\x12\n\n\x06SPLINE\x10\x01\x12\x12\n\x0eMATH_OPERATION\x10\x02\x12\x13\n\x0fJAVA_EXPRESSION\x10\x03\"I\n\x18PolynomialCalibratorInfo\x12\x17\n\x0b\x63oefficient\x18\x01 \x03(\x01\x42\x02\x18\x01\x12\x14\n\x0c\x63oefficients\x18\x02 \x03(\x01\"\xe1\x01\n\x14SplineCalibratorInfo\x12K\n\x05point\x18\x01 \x03(\x0b\x32\x38.yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfoB\x02\x18\x01\x12H\n\x06points\x18\x02 \x03(\x0b\x32\x38.yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo\x1a\x32\n\x0fSplinePointInfo\x12\x0b\n\x03raw\x18\x01 \x01(\x01\x12\x12\n\ncalibrated\x18\x02 \x01(\x01\"/\n\x1cJavaExpressionCalibratorInfo\x12\x0f\n\x07\x66ormula\x18\x01 \x01(\t\">\n\tEnumValue\x12\r\n\x05value\x18\x01 \x01(\x03\x12\r\n\x05label\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\xbc\x07\n\x11ParameterTypeInfo\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x15\n\rqualifiedName\x18\x11 \x01(\t\x12\x18\n\x10shortDescription\x18\x12 \x01(\t\x12\x17\n\x0flongDescription\x18\x13 \x01(\t\x12,\n\x05\x61lias\x18\x14 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x0f\n\x07\x65ngType\x18\x01 \x01(\t\x12:\n\x0c\x64\x61taEncoding\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.DataEncodingInfo\x12-\n\x07unitSet\x18\x03 \x03(\x0b\x32\x1c.yamcs.protobuf.mdb.UnitInfo\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\x04 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12\x30\n\tenumValue\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12>\n\x10\x61\x62soluteTimeInfo\x18\x06 \x01(\x0b\x32$.yamcs.protobuf.mdb.AbsoluteTimeInfo\x12:\n\x0c\x63ontextAlarm\x18\x07 \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\x12.\n\x06member\x18\x08 \x03(\x0b\x32\x1e.yamcs.protobuf.mdb.MemberInfo\x12\x30\n\tarrayInfo\x18\t \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.ArrayInfo\x12O\n\rancillaryData\x18\n \x03(\x0b\x32\x38.yamcs.protobuf.mdb.ParameterTypeInfo.AncillaryDataEntry\x12>\n\x0cnumberFormat\x18\x0b \x01(\x0b\x32(.yamcs.protobuf.mdb.NumberFormatTypeInfo\x12\x0e\n\x06signed\x18\x0c \x01(\x08\x12\x17\n\x0fzeroStringValue\x18\r \x01(\t\x12\x16\n\x0eoneStringValue\x18\x0e \x01(\t\x12\x31\n\x06usedBy\x18\x0f \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x1a[\n\x12\x41ncillaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.mdb.AncillaryDataInfo:\x02\x38\x01\"\xb5\x02\n\x14NumberFormatTypeInfo\x12\x12\n\nnumberBase\x18\x01 \x01(\t\x12\x1d\n\x15minimumFractionDigits\x18\x02 \x01(\x05\x12\x1d\n\x15maximumFractionDigits\x18\x03 \x01(\x05\x12\x1c\n\x14minimumIntegerDigits\x18\x04 \x01(\x05\x12\x1c\n\x14maximumIntegerDigits\x18\x05 \x01(\x05\x12\x16\n\x0enegativeSuffix\x18\x06 \x01(\t\x12\x16\n\x0epositiveSuffix\x18\x07 \x01(\t\x12\x16\n\x0enegativePrefix\x18\x08 \x01(\t\x12\x16\n\x0epositivePrefix\x18\t \x01(\t\x12\x1d\n\x15showThousandsGrouping\x18\n \x01(\x08\x12\x10\n\x08notation\x18\x0b \x01(\t\"5\n\x13GetContainerRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"9\n\x17GetParameterTypeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8d\x01\n\x10\x41\x62soluteTimeInfo\x12\x14\n\x0cinitialValue\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x01\x12\x35\n\noffsetFrom\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\r\n\x05\x65poch\x18\x05 \x01(\t\"\xb0\x01\n\nMemberInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x33\n\x04type\x18\x06 \x01(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\"\xcd\x01\n\x12\x41rgumentMemberInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x32\n\x04type\x18\x06 \x01(\x0b\x32$.yamcs.protobuf.mdb.ArgumentTypeInfo\x12\x14\n\x0cinitialValue\x18\x07 \x01(\t\"\x84\x01\n\x16ParameterDimensionInfo\x12\x12\n\nfixedValue\x18\x01 \x01(\x03\x12\x34\n\tparameter\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\r\n\x05slope\x18\x03 \x01(\x03\x12\x11\n\tintercept\x18\x04 \x01(\x03\"\x80\x01\n\tArrayInfo\x12\x33\n\x04type\x18\x01 \x01(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\x12>\n\ndimensions\x18\x03 \x03(\x0b\x32*.yamcs.protobuf.mdb.ParameterDimensionInfo\"x\n\nUsedByInfo\x12\x34\n\talgorithm\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\x12\x34\n\tcontainer\x18\x02 \x03(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\"\xea\x03\n\rParameterInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x33\n\x04type\x18\x06 \x01(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\x12\x36\n\ndataSource\x18\x07 \x01(\x0e\x32\".yamcs.protobuf.mdb.DataSourceType\x12.\n\x06usedBy\x18\x08 \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.UsedByInfo\x12K\n\rancillaryData\x18\t \x03(\x0b\x32\x34.yamcs.protobuf.mdb.ParameterInfo.AncillaryDataEntry\x12\x0c\n\x04path\x18\n \x03(\t\x1a[\n\x12\x41ncillaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.mdb.AncillaryDataInfo:\x02\x38\x01\"B\n\x11\x41ncillaryDataInfo\x12\r\n\x05value\x18\x01 \x01(\t\x12\x10\n\x08mimeType\x18\x02 \x01(\t\x12\x0c\n\x04href\x18\x03 \x01(\t\"\xad\x04\n\x10\x41rgumentTypeInfo\x12\x0f\n\x07\x65ngType\x18\x01 \x01(\t\x12:\n\x0c\x64\x61taEncoding\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.DataEncodingInfo\x12-\n\x07unitSet\x18\x03 \x03(\x0b\x32\x1c.yamcs.protobuf.mdb.UnitInfo\x12\x30\n\tenumValue\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12\x10\n\x08rangeMin\x18\x06 \x01(\x01\x12\x10\n\x08rangeMax\x18\x07 \x01(\x01\x12\x36\n\x06member\x18\x08 \x03(\x0b\x32&.yamcs.protobuf.mdb.ArgumentMemberInfo\x12\x17\n\x0fzeroStringValue\x18\t \x01(\t\x12\x16\n\x0eoneStringValue\x18\n \x01(\t\x12\x10\n\x08minChars\x18\x0b \x01(\x05\x12\x10\n\x08maxChars\x18\x0c \x01(\x05\x12\x0e\n\x06signed\x18\r \x01(\x08\x12\x10\n\x08minBytes\x18\x0e \x01(\x05\x12\x10\n\x08maxBytes\x18\x0f \x01(\x05\x12=\n\ndimensions\x18\x10 \x03(\x0b\x32).yamcs.protobuf.mdb.ArgumentDimensionInfo\x12\x39\n\x0b\x65lementType\x18\x11 \x01(\x0b\x32$.yamcs.protobuf.mdb.ArgumentTypeInfo\x12\x0c\n\x04name\x18\x12 \x01(\t\"\x95\x01\n\x15\x41rgumentDimensionInfo\x12\x12\n\nfixedValue\x18\x01 \x01(\x03\x12\x34\n\tparameter\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x10\n\x08\x61rgument\x18\x03 \x01(\t\x12\r\n\x05slope\x18\x04 \x01(\x03\x12\x11\n\tintercept\x18\x05 \x01(\x03\"{\n\x0c\x41rgumentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0cinitialValue\x18\x04 \x01(\t\x12\x32\n\x04type\x18\x06 \x01(\x0b\x32$.yamcs.protobuf.mdb.ArgumentTypeInfo\"5\n\x16\x41rgumentAssignmentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe5\x01\n\x10SignificanceInfo\x12T\n\x10\x63onsequenceLevel\x18\x01 \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\x12\x18\n\x10reasonForWarning\x18\x02 \x01(\t\"a\n\x15SignificanceLevelType\x12\x08\n\x04NONE\x10\x01\x12\t\n\x05WATCH\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0c\n\x08\x44ISTRESS\x10\x04\x12\x0c\n\x08\x43RITICAL\x10\x05\x12\n\n\x06SEVERE\x10\x06\"\xdd\x02\n\x0e\x43omparisonInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x41\n\x08operator\x18\x02 \x01(\x0e\x32/.yamcs.protobuf.mdb.ComparisonInfo.OperatorType\x12\r\n\x05value\x18\x03 \x01(\t\x12\x32\n\x08\x61rgument\x18\x04 \x01(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\"\x8e\x01\n\x0cOperatorType\x12\x0c\n\x08\x45QUAL_TO\x10\x01\x12\x10\n\x0cNOT_EQUAL_TO\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x1c\n\x18GREATER_THAN_OR_EQUAL_TO\x10\x04\x12\x10\n\x0cSMALLER_THAN\x10\x05\x12\x1c\n\x18SMALLER_THAN_OR_EQUAL_TO\x10\x06\"A\n\x1aTransmissionConstraintInfo\x12\x12\n\nexpression\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"\xbc\x06\n\x0b\x43ommandInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x34\n\x0b\x62\x61seCommand\x18\x06 \x01(\x0b\x32\x1f.yamcs.protobuf.mdb.CommandInfo\x12\x10\n\x08\x61\x62stract\x18\x07 \x01(\x08\x12\x32\n\x08\x61rgument\x18\x08 \x03(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\x12\x46\n\x12\x61rgumentAssignment\x18\t \x03(\x0b\x32*.yamcs.protobuf.mdb.ArgumentAssignmentInfo\x12:\n\x0csignificance\x18\n \x01(\x0b\x32$.yamcs.protobuf.mdb.SignificanceInfo\x12\x42\n\nconstraint\x18\x0b \x03(\x0b\x32..yamcs.protobuf.mdb.TransmissionConstraintInfo\x12\x42\n\x10\x63ommandContainer\x18\r \x01(\x0b\x32(.yamcs.protobuf.mdb.CommandContainerInfo\x12\x32\n\x08verifier\x18\x0e \x03(\x0b\x32 .yamcs.protobuf.mdb.VerifierInfo\x12I\n\rancillaryData\x18\x0f \x03(\x0b\x32\x32.yamcs.protobuf.mdb.CommandInfo.AncillaryDataEntry\x12\x43\n\x15\x65\x66\x66\x65\x63tiveSignificance\x18\x10 \x01(\x0b\x32$.yamcs.protobuf.mdb.SignificanceInfo\x1a[\n\x12\x41ncillaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.mdb.AncillaryDataInfo:\x02\x38\x01\"\xe5\x03\n\x0cVerifierInfo\x12\r\n\x05stage\x18\x01 \x01(\t\x12\x34\n\tcontainer\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x34\n\talgorithm\x18\x03 \x01(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\x12I\n\tonSuccess\x18\x04 \x01(\x0e\x32\x36.yamcs.protobuf.mdb.VerifierInfo.TerminationActionType\x12\x46\n\x06onFail\x18\x05 \x01(\x0e\x32\x36.yamcs.protobuf.mdb.VerifierInfo.TerminationActionType\x12I\n\tonTimeout\x18\x06 \x01(\x0e\x32\x36.yamcs.protobuf.mdb.VerifierInfo.TerminationActionType\x12\x38\n\x0b\x63heckWindow\x18\x07 \x01(\x0b\x32#.yamcs.protobuf.mdb.CheckWindowInfo\x12\x12\n\nexpression\x18\x08 \x01(\t\".\n\x15TerminationActionType\x12\x0b\n\x07SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\"^\n\x0f\x43heckWindowInfo\x12\x1b\n\x13timeToStartChecking\x18\x01 \x01(\x03\x12\x1a\n\x12timeToStopChecking\x18\x02 \x01(\x03\x12\x12\n\nrelativeTo\x18\x03 \x01(\t\"n\n\nRepeatInfo\x12\x12\n\nfixedCount\x18\x01 \x01(\x03\x12\x37\n\x0c\x64ynamicCount\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x13\n\x0b\x62itsBetween\x18\x03 \x01(\x05\"\x99\x04\n\x11SequenceEntryInfo\x12\x16\n\x0elocationInBits\x18\x01 \x01(\x05\x12V\n\x11referenceLocation\x18\x02 \x01(\x0e\x32;.yamcs.protobuf.mdb.SequenceEntryInfo.ReferenceLocationType\x12\x34\n\tcontainer\x18\x03 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x34\n\tparameter\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x32\n\x08\x61rgument\x18\x06 \x01(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\x12\x36\n\nfixedValue\x18\x07 \x01(\x0b\x32\".yamcs.protobuf.mdb.FixedValueInfo\x12.\n\x06repeat\x18\x05 \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.RepeatInfo\x12J\n\x14indirectParameterRef\x18\x08 \x01(\x0b\x32,.yamcs.protobuf.mdb.IndirectParameterRefInfo\"@\n\x15ReferenceLocationType\x12\x13\n\x0f\x43ONTAINER_START\x10\x01\x12\x12\n\x0ePREVIOUS_ENTRY\x10\x02\"D\n\x0e\x46ixedValueInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08hexValue\x18\x02 \x01(\t\x12\x12\n\nsizeInBits\x18\x03 \x01(\x05\"\xa7\x02\n\x14\x43ommandContainerInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x12\n\nsizeInBits\x18\x06 \x01(\x05\x12?\n\rbaseContainer\x18\x07 \x01(\x0b\x32(.yamcs.protobuf.mdb.CommandContainerInfo\x12\x34\n\x05\x65ntry\x18\x08 \x03(\x0b\x32%.yamcs.protobuf.mdb.SequenceEntryInfo\"h\n\x18IndirectParameterRefInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x16\n\x0e\x61liasNamespace\x18\x02 \x01(\t\"\x8e\x05\n\rContainerInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x13\n\x0bmaxInterval\x18\x06 \x01(\x03\x12\x12\n\nsizeInBits\x18\x07 \x01(\x05\x12\x38\n\rbaseContainer\x18\x08 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x43\n\x13restrictionCriteria\x18\t \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfoB\x02\x18\x01\x12%\n\x1drestrictionCriteriaExpression\x18\r \x01(\t\x12\x34\n\x05\x65ntry\x18\n \x03(\x0b\x32%.yamcs.protobuf.mdb.SequenceEntryInfo\x12.\n\x06usedBy\x18\x0b \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.UsedByInfo\x12K\n\rancillaryData\x18\x0c \x03(\x0b\x32\x34.yamcs.protobuf.mdb.ContainerInfo.AncillaryDataEntry\x12\x18\n\x10\x61rchivePartition\x18\x0e \x01(\x08\x1a[\n\x12\x41ncillaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.mdb.AncillaryDataInfo:\x02\x38\x01\"\xbf\x01\n\x12InputParameterInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x11\n\tinputName\x18\x02 \x01(\t\x12\x19\n\x11parameterInstance\x18\x03 \x01(\x05\x12\x11\n\tmandatory\x18\x04 \x01(\x08\x12\x32\n\x08\x61rgument\x18\x05 \x01(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\"_\n\x13OutputParameterInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x12\n\noutputName\x18\x02 \x01(\t\"\x87\x02\n\x0bMathElement\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.yamcs.protobuf.mdb.MathElement.Type\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x34\n\tparameter\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x19\n\x11parameterInstance\x18\x05 \x01(\x05\"R\n\x04Type\x12\x11\n\rVALUE_OPERAND\x10\x01\x12\x1a\n\x16THIS_PARAMETER_OPERAND\x10\x02\x12\x0c\n\x08OPERATOR\x10\x03\x12\r\n\tPARAMETER\x10\x04\"\x99\x05\n\rAlgorithmInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x36\n\x05scope\x18\x06 \x01(\x0e\x32\'.yamcs.protobuf.mdb.AlgorithmInfo.Scope\x12\x34\n\x04type\x18\r \x01(\x0e\x32&.yamcs.protobuf.mdb.AlgorithmInfo.Type\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x0c\n\x04text\x18\x08 \x01(\t\x12>\n\x0einputParameter\x18\t \x03(\x0b\x32&.yamcs.protobuf.mdb.InputParameterInfo\x12@\n\x0foutputParameter\x18\n \x03(\x0b\x32\'.yamcs.protobuf.mdb.OutputParameterInfo\x12<\n\x11onParameterUpdate\x18\x0b \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x16\n\x0eonPeriodicRate\x18\x0c \x03(\x03\x12\x35\n\x0cmathElements\x18\x0e \x03(\x0b\x32\x1f.yamcs.protobuf.mdb.MathElement\"\x1c\n\x04Type\x12\n\n\x06\x43USTOM\x10\x01\x12\x08\n\x04MATH\x10\x02\"G\n\x05Scope\x12\n\n\x06GLOBAL\x10\x00\x12\x18\n\x14\x43OMMAND_VERIFICATION\x10\x01\x12\x18\n\x14\x43ONTAINER_PROCESSING\x10\x02\"`\n\x17ListSpaceSystemsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\"n\n\x15ListContainersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x0e\n\x06system\x18\n \x01(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\"r\n\x19ListParameterTypesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x0e\n\x06system\x18\n \x01(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\"\xa6\x01\n\x15ListAlgorithmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x0e\n\x06system\x18\n \x01(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\x12\x36\n\x05scope\x18\x0b \x01(\x0e\x32\'.yamcs.protobuf.mdb.AlgorithmInfo.Scope\"\x91\x01\n\x13ListCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x0e\n\x06system\x18\x0b \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x08\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\x12\x12\n\nnoAbstract\x18\n \x01(\x08\"5\n\x13GetParameterRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd8\x01\n\x15ListParametersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\t\n\x01q\x18\x02 \x01(\t\x12\x15\n\rsearchMembers\x18\x0c \x01(\x08\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x08\x12\x0c\n\x04type\x18\x05 \x03(\t\x12\x32\n\x06source\x18\n \x01(\x0e\x32\".yamcs.protobuf.mdb.DataSourceType\x12\x0e\n\x06system\x18\x0b \x01(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12\x0b\n\x03pos\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\"\xcd\x01\n\x16ListParametersResponse\x12\x34\n\x07systems\x18\x05 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x18\n\x0cspaceSystems\x18\x04 \x03(\tB\x02\x18\x01\x12\x35\n\nparameters\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"X\n\x19\x42\x61tchGetParametersRequest\x12\x10\n\x08instance\x18\x02 \x01(\t\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\"\xec\x01\n\x1a\x42\x61tchGetParametersResponse\x12U\n\x08response\x18\x01 \x03(\x0b\x32\x43.yamcs.protobuf.mdb.BatchGetParametersResponse.GetParameterResponse\x1aw\n\x14GetParameterResponse\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x34\n\tparameter\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\"\xcd\x01\n\x16ListContainersResponse\x12\x34\n\x07systems\x18\x05 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x18\n\x0cspaceSystems\x18\x04 \x03(\tB\x02\x18\x01\x12\x35\n\ncontainers\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\xd9\x01\n\x1aListParameterTypesResponse\x12\x34\n\x07systems\x18\x05 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x18\n\x0cspaceSystems\x18\x04 \x03(\tB\x02\x18\x01\x12=\n\x0eparameterTypes\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\xc7\x01\n\x14ListCommandsResponse\x12\x34\n\x07systems\x18\x05 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x18\n\x0cspaceSystems\x18\x04 \x03(\tB\x02\x18\x01\x12\x31\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.mdb.CommandInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\xcd\x01\n\x16ListAlgorithmsResponse\x12\x34\n\x07systems\x18\x05 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x18\n\x0cspaceSystems\x18\x04 \x03(\tB\x02\x18\x01\x12\x35\n\nalgorithms\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"5\n\x13GetAlgorithmRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb4\x02\n\x16\x43reateParameterRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12H\n\x07\x61liases\x18\x05 \x03(\x0b\x32\x37.yamcs.protobuf.mdb.CreateParameterRequest.AliasesEntry\x12\x36\n\ndataSource\x18\x06 \x01(\x0e\x32\".yamcs.protobuf.mdb.DataSourceType\x12\x15\n\rparameterType\x18\x07 \x01(\t\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x03\n\x1a\x43reateParameterTypeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12L\n\x07\x61liases\x18\x05 \x03(\x0b\x32;.yamcs.protobuf.mdb.CreateParameterTypeRequest.AliasesEntry\x12\x0f\n\x07\x65ngType\x18\x06 \x01(\t\x12\x0c\n\x04unit\x18\x07 \x01(\t\x12\x0e\n\x06signed\x18\x08 \x01(\x08\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\t \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12;\n\rcontextAlarms\x18\n \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\x12\x38\n\x11\x65numerationValues\x18\x0b \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12\x17\n\x0fzeroStringValue\x18\x0c \x01(\t\x12\x16\n\x0eoneStringValue\x18\r \x01(\t\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x19GetMissionDatabaseRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"4\n ExportJavaMissionDatabaseRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\xd6\x01\n\x1cStreamMissionDatabaseRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x1b\n\x13includeSpaceSystems\x18\x02 \x01(\x08\x12\x19\n\x11includeContainers\x18\x03 \x01(\x08\x12\x19\n\x11includeParameters\x18\x04 \x01(\x08\x12\x1d\n\x15includeParameterTypes\x18\x05 \x01(\x08\x12\x17\n\x0fincludeCommands\x18\x06 \x01(\x08\x12\x19\n\x11includeAlgorithms\x18\x07 \x01(\x08\"\xf5\x02\n\x13MissionDatabaseItem\x12:\n\x0bspaceSystem\x18\x01 \x01(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfoH\x00\x12\x36\n\tcontainer\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfoH\x00\x12\x36\n\tparameter\x18\x03 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfoH\x00\x12>\n\rparameterType\x18\x04 \x01(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfoH\x00\x12\x32\n\x07\x63ommand\x18\x05 \x01(\x0b\x32\x1f.yamcs.protobuf.mdb.CommandInfoH\x00\x12\x36\n\talgorithm\x18\x06 \x01(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfoH\x00\x42\x06\n\x04item\"\x83\x01\n\x18ListSpaceSystemsResponse\x12\x39\n\x0cspaceSystems\x18\x01 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"7\n\x15GetSpaceSystemRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"3\n\x11\x45xportXtceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"3\n\x11GetCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb8\x03\n\x0fSpaceSystemInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x10 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x30\n\x07history\x18\x0e \x03(\x0b\x32\x1f.yamcs.protobuf.mdb.HistoryInfo\x12\x30\n\x03sub\x18\x0f \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12M\n\rancillaryData\x18\x11 \x03(\x0b\x32\x36.yamcs.protobuf.mdb.SpaceSystemInfo.AncillaryDataEntry\x1a[\n\x12\x41ncillaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.mdb.AncillaryDataInfo:\x02\x38\x01*\xae\x01\n\x0e\x44\x61taSourceType\x12\x0f\n\x0bTELEMETERED\x10\x00\x12\x0b\n\x07\x44\x45RIVED\x10\x01\x12\x0c\n\x08\x43ONSTANT\x10\x02\x12\t\n\x05LOCAL\x10\x03\x12\n\n\x06SYSTEM\x10\x04\x12\x0b\n\x07\x43OMMAND\x10\x05\x12\x13\n\x0f\x43OMMAND_HISTORY\x10\x06\x12\r\n\tEXTERNAL1\x10\x07\x12\r\n\tEXTERNAL2\x10\x08\x12\r\n\tEXTERNAL3\x10\t\x12\n\n\x06GROUND\x10\n*\\\n\x0e\x41larmLevelType\x12\n\n\x06NORMAL\x10\x00\x12\t\n\x05WATCH\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\x0c\n\x08\x44ISTRESS\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x12\n\n\x06SEVERE\x10\x05\x32\xba\x16\n\x06MdbApi\x12\x83\x01\n\x12GetMissionDatabase\x12-.yamcs.protobuf.mdb.GetMissionDatabaseRequest\x1a#.yamcs.protobuf.mdb.MissionDatabase\"\x19\x8a\x92\x03\x15\n\x13/api/mdb/{instance}\x12\x8c\x01\n\x19\x45xportJavaMissionDatabase\x12\x34.yamcs.protobuf.mdb.ExportJavaMissionDatabaseRequest\x1a\x13.yamcs.api.HttpBody\"$\x8a\x92\x03 \n\x1e/api/mdb/{instance}:exportJava\x12\xa4\x01\n\x10ListSpaceSystems\x12+.yamcs.protobuf.mdb.ListSpaceSystemsRequest\x1a,.yamcs.protobuf.mdb.ListSpaceSystemsResponse\"5\x8a\x92\x03\x31\n!/api/mdb/{instance}/space-systemsR\x0cspaceSystems\x12\x91\x01\n\x0eGetSpaceSystem\x12).yamcs.protobuf.mdb.GetSpaceSystemRequest\x1a#.yamcs.protobuf.mdb.SpaceSystemInfo\"/\x8a\x92\x03+\n)/api/mdb/{instance}/space-systems/{name*}\x12\x84\x01\n\nExportXtce\x12%.yamcs.protobuf.mdb.ExportXtceRequest\x1a\x13.yamcs.api.HttpBody\":\x8a\x92\x03\x36\n4/api/mdb/{instance}/space-systems/{name*}:exportXTCE\x12\xa7\x01\n\x15StreamMissionDatabase\x12\x30.yamcs.protobuf.mdb.StreamMissionDatabaseRequest\x1a\'.yamcs.protobuf.mdb.MissionDatabaseItem\"1\x8a\x92\x03-\n)/api/mdb/{instance}:streamMissionDatabaseH\x01\x30\x01\x12\x99\x01\n\x0eListParameters\x12).yamcs.protobuf.mdb.ListParametersRequest\x1a*.yamcs.protobuf.mdb.ListParametersResponse\"0\x8a\x92\x03,\n\x1e/api/mdb/{instance}/parametersR\nparameters\x12\x88\x01\n\x0cGetParameter\x12\'.yamcs.protobuf.mdb.GetParameterRequest\x1a!.yamcs.protobuf.mdb.ParameterInfo\",\x8a\x92\x03(\n&/api/mdb/{instance}/parameters/{name*}\x12\x89\x01\n\x0f\x43reateParameter\x12*.yamcs.protobuf.mdb.CreateParameterRequest\x1a!.yamcs.protobuf.mdb.ParameterInfo\"\'\x8a\x92\x03#\x1a\x1e/api/mdb/{instance}/parameters:\x01*\x12\xa5\x01\n\x12\x42\x61tchGetParameters\x12-.yamcs.protobuf.mdb.BatchGetParametersRequest\x1a..yamcs.protobuf.mdb.BatchGetParametersResponse\"0\x8a\x92\x03,\x1a\'/api/mdb/{instance}/parameters:batchGet:\x01*\x12\xae\x01\n\x12ListParameterTypes\x12-.yamcs.protobuf.mdb.ListParameterTypesRequest\x1a..yamcs.protobuf.mdb.ListParameterTypesResponse\"9\x8a\x92\x03\x35\n#/api/mdb/{instance}/parameter-typesR\x0eparameterTypes\x12\x99\x01\n\x10GetParameterType\x12+.yamcs.protobuf.mdb.GetParameterTypeRequest\x1a%.yamcs.protobuf.mdb.ParameterTypeInfo\"1\x8a\x92\x03-\n+/api/mdb/{instance}/parameter-types/{name*}\x12\x9a\x01\n\x13\x43reateParameterType\x12..yamcs.protobuf.mdb.CreateParameterTypeRequest\x1a%.yamcs.protobuf.mdb.ParameterTypeInfo\",\x8a\x92\x03(\x1a#/api/mdb/{instance}/parameter-types:\x01*\x12\x99\x01\n\x0eListContainers\x12).yamcs.protobuf.mdb.ListContainersRequest\x1a*.yamcs.protobuf.mdb.ListContainersResponse\"0\x8a\x92\x03,\n\x1e/api/mdb/{instance}/containersR\ncontainers\x12\x88\x01\n\x0cGetContainer\x12\'.yamcs.protobuf.mdb.GetContainerRequest\x1a!.yamcs.protobuf.mdb.ContainerInfo\",\x8a\x92\x03(\n&/api/mdb/{instance}/containers/{name*}\x12\x8f\x01\n\x0cListCommands\x12\'.yamcs.protobuf.mdb.ListCommandsRequest\x1a(.yamcs.protobuf.mdb.ListCommandsResponse\",\x8a\x92\x03(\n\x1c/api/mdb/{instance}/commandsR\x08\x63ommands\x12\x80\x01\n\nGetCommand\x12%.yamcs.protobuf.mdb.GetCommandRequest\x1a\x1f.yamcs.protobuf.mdb.CommandInfo\"*\x8a\x92\x03&\n$/api/mdb/{instance}/commands/{name*}\x12\x99\x01\n\x0eListAlgorithms\x12).yamcs.protobuf.mdb.ListAlgorithmsRequest\x1a*.yamcs.protobuf.mdb.ListAlgorithmsResponse\"0\x8a\x92\x03,\n\x1e/api/mdb/{instance}/algorithmsR\nalgorithms\x12\x88\x01\n\x0cGetAlgorithm\x12\'.yamcs.protobuf.mdb.GetAlgorithmRequest\x1a!.yamcs.protobuf.mdb.AlgorithmInfo\",\x8a\x92\x03(\n&/api/mdb/{instance}/algorithms/{name*}\x1a\x07\x82\x80\x01\x03MDBB\x14\n\x12org.yamcs.protobuf'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])

_DATASOURCETYPE = _descriptor.EnumDescriptor(
  name='DataSourceType',
  full_name='yamcs.protobuf.mdb.DataSourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TELEMETERED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DERIVED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSTANT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_HISTORY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL1', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL2', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL3', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUND', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16022,
  serialized_end=16196,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCETYPE)

DataSourceType = enum_type_wrapper.EnumTypeWrapper(_DATASOURCETYPE)
_ALARMLEVELTYPE = _descriptor.EnumDescriptor(
  name='AlarmLevelType',
  full_name='yamcs.protobuf.mdb.AlarmLevelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATCH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTRESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16198,
  serialized_end=16290,
)
_sym_db.RegisterEnumDescriptor(_ALARMLEVELTYPE)

AlarmLevelType = enum_type_wrapper.EnumTypeWrapper(_ALARMLEVELTYPE)
TELEMETERED = 0
DERIVED = 1
CONSTANT = 2
LOCAL = 3
SYSTEM = 4
COMMAND = 5
COMMAND_HISTORY = 6
EXTERNAL1 = 7
EXTERNAL2 = 8
EXTERNAL3 = 9
GROUND = 10
NORMAL = 0
WATCH = 1
WARNING = 2
DISTRESS = 3
CRITICAL = 4
SEVERE = 5


_DATAENCODINGINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.DataEncodingInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1571,
  serialized_end=1638,
)
_sym_db.RegisterEnumDescriptor(_DATAENCODINGINFO_TYPE)

_CALIBRATORINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.CalibratorInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POLYNOMIAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPLINE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATH_OPERATION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JAVA_EXPRESSION', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2097,
  serialized_end=2172,
)
_sym_db.RegisterEnumDescriptor(_CALIBRATORINFO_TYPE)

_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE = _descriptor.EnumDescriptor(
  name='SignificanceLevelType',
  full_name='yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATCH', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTRESS', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6480,
  serialized_end=6577,
)
_sym_db.RegisterEnumDescriptor(_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE)

_COMPARISONINFO_OPERATORTYPE = _descriptor.EnumDescriptor(
  name='OperatorType',
  full_name='yamcs.protobuf.mdb.ComparisonInfo.OperatorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TO', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL_TO', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_OR_EQUAL_TO', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALLER_THAN', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALLER_THAN_OR_EQUAL_TO', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6787,
  serialized_end=6929,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONINFO_OPERATORTYPE)

_VERIFIERINFO_TERMINATIONACTIONTYPE = _descriptor.EnumDescriptor(
  name='TerminationActionType',
  full_name='yamcs.protobuf.mdb.VerifierInfo.TerminationActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8269,
  serialized_end=8315,
)
_sym_db.RegisterEnumDescriptor(_VERIFIERINFO_TERMINATIONACTIONTYPE)

_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE = _descriptor.EnumDescriptor(
  name='ReferenceLocationType',
  full_name='yamcs.protobuf.mdb.SequenceEntryInfo.ReferenceLocationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_START', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVIOUS_ENTRY', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8999,
  serialized_end=9063,
)
_sym_db.RegisterEnumDescriptor(_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE)

_MATHELEMENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.MathElement.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VALUE_OPERAND', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIS_PARAMETER_OPERAND', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETER', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10669,
  serialized_end=10751,
)
_sym_db.RegisterEnumDescriptor(_MATHELEMENT_TYPE)

_ALGORITHMINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.AlgorithmInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATH', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11318,
  serialized_end=11346,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMINFO_TYPE)

_ALGORITHMINFO_SCOPE = _descriptor.EnumDescriptor(
  name='Scope',
  full_name='yamcs.protobuf.mdb.AlgorithmInfo.Scope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GLOBAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_VERIFICATION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_PROCESSING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11348,
  serialized_end=11419,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMINFO_SCOPE)


_MISSIONDATABASE = _descriptor.Descriptor(
  name='MissionDatabase',
  full_name='yamcs.protobuf.mdb.MissionDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configName', full_name='yamcs.protobuf.mdb.MissionDatabase.configName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.MissionDatabase.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.MissionDatabase.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystem', full_name='yamcs.protobuf.mdb.MissionDatabase.spaceSystem', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.MissionDatabase.spaceSystems', index=4,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterCount', full_name='yamcs.protobuf.mdb.MissionDatabase.parameterCount', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containerCount', full_name='yamcs.protobuf.mdb.MissionDatabase.containerCount', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandCount', full_name='yamcs.protobuf.mdb.MissionDatabase.commandCount', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithmCount', full_name='yamcs.protobuf.mdb.MissionDatabase.algorithmCount', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterTypeCount', full_name='yamcs.protobuf.mdb.MissionDatabase.parameterTypeCount', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=447,
)


_HISTORYINFO = _descriptor.Descriptor(
  name='HistoryInfo',
  full_name='yamcs.protobuf.mdb.HistoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.HistoryInfo.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='yamcs.protobuf.mdb.HistoryInfo.date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.mdb.HistoryInfo.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='yamcs.protobuf.mdb.HistoryInfo.author', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=526,
)


_UNITINFO = _descriptor.Descriptor(
  name='UnitInfo',
  full_name='yamcs.protobuf.mdb.UnitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='yamcs.protobuf.mdb.UnitInfo.unit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=552,
)


_ALARMRANGE = _descriptor.Descriptor(
  name='AlarmRange',
  full_name='yamcs.protobuf.mdb.AlarmRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.mdb.AlarmRange.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minInclusive', full_name='yamcs.protobuf.mdb.AlarmRange.minInclusive', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxInclusive', full_name='yamcs.protobuf.mdb.AlarmRange.maxInclusive', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minExclusive', full_name='yamcs.protobuf.mdb.AlarmRange.minExclusive', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxExclusive', full_name='yamcs.protobuf.mdb.AlarmRange.maxExclusive', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=706,
)


_ENUMERATIONALARM = _descriptor.Descriptor(
  name='EnumerationAlarm',
  full_name='yamcs.protobuf.mdb.EnumerationAlarm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.mdb.EnumerationAlarm.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.mdb.EnumerationAlarm.label', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=792,
)


_ALARMINFO = _descriptor.Descriptor(
  name='AlarmInfo',
  full_name='yamcs.protobuf.mdb.AlarmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minViolations', full_name='yamcs.protobuf.mdb.AlarmInfo.minViolations', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticAlarmRange', full_name='yamcs.protobuf.mdb.AlarmInfo.staticAlarmRange', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticAlarmRanges', full_name='yamcs.protobuf.mdb.AlarmInfo.staticAlarmRanges', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumerationAlarm', full_name='yamcs.protobuf.mdb.AlarmInfo.enumerationAlarm', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumerationAlarms', full_name='yamcs.protobuf.mdb.AlarmInfo.enumerationAlarms', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=1083,
)


_CONTEXTALARMINFO = _descriptor.Descriptor(
  name='ContextAlarmInfo',
  full_name='yamcs.protobuf.mdb.ContextAlarmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.comparison', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarm', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.alarm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1223,
)


_DATAENCODINGINFO = _descriptor.Descriptor(
  name='DataEncodingInfo',
  full_name='yamcs.protobuf.mdb.DataEncodingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.DataEncodingInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='littleEndian', full_name='yamcs.protobuf.mdb.DataEncodingInfo.littleEndian', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.DataEncodingInfo.sizeInBits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='yamcs.protobuf.mdb.DataEncodingInfo.encoding', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultCalibrator', full_name='yamcs.protobuf.mdb.DataEncodingInfo.defaultCalibrator', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrator', full_name='yamcs.protobuf.mdb.DataEncodingInfo.contextCalibrator', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrators', full_name='yamcs.protobuf.mdb.DataEncodingInfo.contextCalibrators', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAENCODINGINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1226,
  serialized_end=1638,
)


_CONTEXTCALIBRATORINFO = _descriptor.Descriptor(
  name='ContextCalibratorInfo',
  full_name='yamcs.protobuf.mdb.ContextCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.comparison', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrator', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.calibrator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1793,
)


_CALIBRATORINFO = _descriptor.Descriptor(
  name='CalibratorInfo',
  full_name='yamcs.protobuf.mdb.CalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='polynomialCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.polynomialCalibrator', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='splineCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.splineCalibrator', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='javaExpressionCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.javaExpressionCalibrator', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.CalibratorInfo.type', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CALIBRATORINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1796,
  serialized_end=2172,
)


_POLYNOMIALCALIBRATORINFO = _descriptor.Descriptor(
  name='PolynomialCalibratorInfo',
  full_name='yamcs.protobuf.mdb.PolynomialCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficient', full_name='yamcs.protobuf.mdb.PolynomialCalibratorInfo.coefficient', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='yamcs.protobuf.mdb.PolynomialCalibratorInfo.coefficients', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2247,
)


_SPLINECALIBRATORINFO_SPLINEPOINTINFO = _descriptor.Descriptor(
  name='SplinePointInfo',
  full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo.raw', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrated', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo.calibrated', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2475,
)

_SPLINECALIBRATORINFO = _descriptor.Descriptor(
  name='SplineCalibratorInfo',
  full_name='yamcs.protobuf.mdb.SplineCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPLINECALIBRATORINFO_SPLINEPOINTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2250,
  serialized_end=2475,
)


_JAVAEXPRESSIONCALIBRATORINFO = _descriptor.Descriptor(
  name='JavaExpressionCalibratorInfo',
  full_name='yamcs.protobuf.mdb.JavaExpressionCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula', full_name='yamcs.protobuf.mdb.JavaExpressionCalibratorInfo.formula', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2477,
  serialized_end=2524,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='yamcs.protobuf.mdb.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.EnumValue.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.mdb.EnumValue.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.mdb.EnumValue.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2526,
  serialized_end=2588,
)


_PARAMETERTYPEINFO_ANCILLARYDATAENTRY = _descriptor.Descriptor(
  name='AncillaryDataEntry',
  full_name='yamcs.protobuf.mdb.ParameterTypeInfo.AncillaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.AncillaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.AncillaryDataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3547,
)

_PARAMETERTYPEINFO = _descriptor.Descriptor(
  name='ParameterTypeInfo',
  full_name='yamcs.protobuf.mdb.ParameterTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.name', index=0,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.qualifiedName', index=1,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.shortDescription', index=2,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.longDescription', index=3,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.alias', index=4,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.engType', index=5,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataEncoding', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.dataEncoding', index=6,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unitSet', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.unitSet', index=7,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.defaultAlarm', index=8,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.enumValue', index=9,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absoluteTimeInfo', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.absoluteTimeInfo', index=10,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarm', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.contextAlarm', index=11,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='member', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.member', index=12,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrayInfo', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.arrayInfo', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ancillaryData', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.ancillaryData', index=14,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberFormat', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.numberFormat', index=15,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.signed', index=16,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zeroStringValue', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.zeroStringValue', index=17,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oneStringValue', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.oneStringValue', index=18,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedBy', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.usedBy', index=19,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARAMETERTYPEINFO_ANCILLARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=3547,
)


_NUMBERFORMATTYPEINFO = _descriptor.Descriptor(
  name='NumberFormatTypeInfo',
  full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numberBase', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.numberBase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimumFractionDigits', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.minimumFractionDigits', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximumFractionDigits', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.maximumFractionDigits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimumIntegerDigits', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.minimumIntegerDigits', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximumIntegerDigits', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.maximumIntegerDigits', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negativeSuffix', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.negativeSuffix', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='positiveSuffix', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.positiveSuffix', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negativePrefix', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.negativePrefix', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='positivePrefix', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.positivePrefix', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showThousandsGrouping', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.showThousandsGrouping', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notation', full_name='yamcs.protobuf.mdb.NumberFormatTypeInfo.notation', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3550,
  serialized_end=3859,
)


_GETCONTAINERREQUEST = _descriptor.Descriptor(
  name='GetContainerRequest',
  full_name='yamcs.protobuf.mdb.GetContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetContainerRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetContainerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3861,
  serialized_end=3914,
)


_GETPARAMETERTYPEREQUEST = _descriptor.Descriptor(
  name='GetParameterTypeRequest',
  full_name='yamcs.protobuf.mdb.GetParameterTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetParameterTypeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetParameterTypeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3916,
  serialized_end=3973,
)


_ABSOLUTETIMEINFO = _descriptor.Descriptor(
  name='AbsoluteTimeInfo',
  full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialValue', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.initialValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.scale', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offsetFrom', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.offsetFrom', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.epoch', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3976,
  serialized_end=4117,
)


_MEMBERINFO = _descriptor.Descriptor(
  name='MemberInfo',
  full_name='yamcs.protobuf.mdb.MemberInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.MemberInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.MemberInfo.shortDescription', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.MemberInfo.longDescription', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.MemberInfo.alias', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.MemberInfo.type', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4120,
  serialized_end=4296,
)


_ARGUMENTMEMBERINFO = _descriptor.Descriptor(
  name='ArgumentMemberInfo',
  full_name='yamcs.protobuf.mdb.ArgumentMemberInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.shortDescription', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.longDescription', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.alias', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.type', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initialValue', full_name='yamcs.protobuf.mdb.ArgumentMemberInfo.initialValue', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4299,
  serialized_end=4504,
)


_PARAMETERDIMENSIONINFO = _descriptor.Descriptor(
  name='ParameterDimensionInfo',
  full_name='yamcs.protobuf.mdb.ParameterDimensionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixedValue', full_name='yamcs.protobuf.mdb.ParameterDimensionInfo.fixedValue', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.ParameterDimensionInfo.parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slope', full_name='yamcs.protobuf.mdb.ParameterDimensionInfo.slope', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intercept', full_name='yamcs.protobuf.mdb.ParameterDimensionInfo.intercept', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4507,
  serialized_end=4639,
)


_ARRAYINFO = _descriptor.Descriptor(
  name='ArrayInfo',
  full_name='yamcs.protobuf.mdb.ArrayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ArrayInfo.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='yamcs.protobuf.mdb.ArrayInfo.dimensions', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4642,
  serialized_end=4770,
)


_USEDBYINFO = _descriptor.Descriptor(
  name='UsedByInfo',
  full_name='yamcs.protobuf.mdb.UsedByInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.UsedByInfo.algorithm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.UsedByInfo.container', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4772,
  serialized_end=4892,
)


_PARAMETERINFO_ANCILLARYDATAENTRY = _descriptor.Descriptor(
  name='AncillaryDataEntry',
  full_name='yamcs.protobuf.mdb.ParameterInfo.AncillaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.ParameterInfo.AncillaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ParameterInfo.AncillaryDataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3547,
)

_PARAMETERINFO = _descriptor.Descriptor(
  name='ParameterInfo',
  full_name='yamcs.protobuf.mdb.ParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ParameterInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.ParameterInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ParameterInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ParameterInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ParameterInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ParameterInfo.type', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSource', full_name='yamcs.protobuf.mdb.ParameterInfo.dataSource', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedBy', full_name='yamcs.protobuf.mdb.ParameterInfo.usedBy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ancillaryData', full_name='yamcs.protobuf.mdb.ParameterInfo.ancillaryData', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='yamcs.protobuf.mdb.ParameterInfo.path', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARAMETERINFO_ANCILLARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4895,
  serialized_end=5385,
)


_ANCILLARYDATAINFO = _descriptor.Descriptor(
  name='AncillaryDataInfo',
  full_name='yamcs.protobuf.mdb.AncillaryDataInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.AncillaryDataInfo.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mimeType', full_name='yamcs.protobuf.mdb.AncillaryDataInfo.mimeType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='href', full_name='yamcs.protobuf.mdb.AncillaryDataInfo.href', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5387,
  serialized_end=5453,
)


_ARGUMENTTYPEINFO = _descriptor.Descriptor(
  name='ArgumentTypeInfo',
  full_name='yamcs.protobuf.mdb.ArgumentTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.engType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataEncoding', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.dataEncoding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unitSet', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.unitSet', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.enumValue', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangeMin', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.rangeMin', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangeMax', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.rangeMax', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='member', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.member', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zeroStringValue', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.zeroStringValue', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oneStringValue', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.oneStringValue', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minChars', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.minChars', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxChars', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.maxChars', index=10,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.signed', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minBytes', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.minBytes', index=12,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxBytes', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.maxBytes', index=13,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.dimensions', index=14,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elementType', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.elementType', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.name', index=16,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5456,
  serialized_end=6013,
)


_ARGUMENTDIMENSIONINFO = _descriptor.Descriptor(
  name='ArgumentDimensionInfo',
  full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixedValue', full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo.fixedValue', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo.parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo.argument', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slope', full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo.slope', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intercept', full_name='yamcs.protobuf.mdb.ArgumentDimensionInfo.intercept', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6016,
  serialized_end=6165,
)


_ARGUMENTINFO = _descriptor.Descriptor(
  name='ArgumentInfo',
  full_name='yamcs.protobuf.mdb.ArgumentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.mdb.ArgumentInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initialValue', full_name='yamcs.protobuf.mdb.ArgumentInfo.initialValue', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ArgumentInfo.type', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6167,
  serialized_end=6290,
)


_ARGUMENTASSIGNMENTINFO = _descriptor.Descriptor(
  name='ArgumentAssignmentInfo',
  full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6292,
  serialized_end=6345,
)


_SIGNIFICANCEINFO = _descriptor.Descriptor(
  name='SignificanceInfo',
  full_name='yamcs.protobuf.mdb.SignificanceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='consequenceLevel', full_name='yamcs.protobuf.mdb.SignificanceInfo.consequenceLevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reasonForWarning', full_name='yamcs.protobuf.mdb.SignificanceInfo.reasonForWarning', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6348,
  serialized_end=6577,
)


_COMPARISONINFO = _descriptor.Descriptor(
  name='ComparisonInfo',
  full_name='yamcs.protobuf.mdb.ComparisonInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.ComparisonInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='yamcs.protobuf.mdb.ComparisonInfo.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ComparisonInfo.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.ComparisonInfo.argument', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARISONINFO_OPERATORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6580,
  serialized_end=6929,
)


_TRANSMISSIONCONSTRAINTINFO = _descriptor.Descriptor(
  name='TransmissionConstraintInfo',
  full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expression', full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo.expression', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6931,
  serialized_end=6996,
)


_COMMANDINFO_ANCILLARYDATAENTRY = _descriptor.Descriptor(
  name='AncillaryDataEntry',
  full_name='yamcs.protobuf.mdb.CommandInfo.AncillaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.CommandInfo.AncillaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.CommandInfo.AncillaryDataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3547,
)

_COMMANDINFO = _descriptor.Descriptor(
  name='CommandInfo',
  full_name='yamcs.protobuf.mdb.CommandInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CommandInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.CommandInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CommandInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CommandInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.CommandInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseCommand', full_name='yamcs.protobuf.mdb.CommandInfo.baseCommand', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abstract', full_name='yamcs.protobuf.mdb.CommandInfo.abstract', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.CommandInfo.argument', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argumentAssignment', full_name='yamcs.protobuf.mdb.CommandInfo.argumentAssignment', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='significance', full_name='yamcs.protobuf.mdb.CommandInfo.significance', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='yamcs.protobuf.mdb.CommandInfo.constraint', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandContainer', full_name='yamcs.protobuf.mdb.CommandInfo.commandContainer', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifier', full_name='yamcs.protobuf.mdb.CommandInfo.verifier', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ancillaryData', full_name='yamcs.protobuf.mdb.CommandInfo.ancillaryData', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effectiveSignificance', full_name='yamcs.protobuf.mdb.CommandInfo.effectiveSignificance', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDINFO_ANCILLARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6999,
  serialized_end=7827,
)


_VERIFIERINFO = _descriptor.Descriptor(
  name='VerifierInfo',
  full_name='yamcs.protobuf.mdb.VerifierInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage', full_name='yamcs.protobuf.mdb.VerifierInfo.stage', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.VerifierInfo.container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.VerifierInfo.algorithm', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onSuccess', full_name='yamcs.protobuf.mdb.VerifierInfo.onSuccess', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onFail', full_name='yamcs.protobuf.mdb.VerifierInfo.onFail', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onTimeout', full_name='yamcs.protobuf.mdb.VerifierInfo.onTimeout', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checkWindow', full_name='yamcs.protobuf.mdb.VerifierInfo.checkWindow', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expression', full_name='yamcs.protobuf.mdb.VerifierInfo.expression', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VERIFIERINFO_TERMINATIONACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7830,
  serialized_end=8315,
)


_CHECKWINDOWINFO = _descriptor.Descriptor(
  name='CheckWindowInfo',
  full_name='yamcs.protobuf.mdb.CheckWindowInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeToStartChecking', full_name='yamcs.protobuf.mdb.CheckWindowInfo.timeToStartChecking', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeToStopChecking', full_name='yamcs.protobuf.mdb.CheckWindowInfo.timeToStopChecking', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relativeTo', full_name='yamcs.protobuf.mdb.CheckWindowInfo.relativeTo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8317,
  serialized_end=8411,
)


_REPEATINFO = _descriptor.Descriptor(
  name='RepeatInfo',
  full_name='yamcs.protobuf.mdb.RepeatInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixedCount', full_name='yamcs.protobuf.mdb.RepeatInfo.fixedCount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamicCount', full_name='yamcs.protobuf.mdb.RepeatInfo.dynamicCount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitsBetween', full_name='yamcs.protobuf.mdb.RepeatInfo.bitsBetween', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8413,
  serialized_end=8523,
)


_SEQUENCEENTRYINFO = _descriptor.Descriptor(
  name='SequenceEntryInfo',
  full_name='yamcs.protobuf.mdb.SequenceEntryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locationInBits', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.locationInBits', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceLocation', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.referenceLocation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.container', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.parameter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.argument', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixedValue', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.fixedValue', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.repeat', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indirectParameterRef', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.indirectParameterRef', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8526,
  serialized_end=9063,
)


_FIXEDVALUEINFO = _descriptor.Descriptor(
  name='FixedValueInfo',
  full_name='yamcs.protobuf.mdb.FixedValueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.FixedValueInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hexValue', full_name='yamcs.protobuf.mdb.FixedValueInfo.hexValue', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.FixedValueInfo.sizeInBits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9065,
  serialized_end=9133,
)


_COMMANDCONTAINERINFO = _descriptor.Descriptor(
  name='CommandContainerInfo',
  full_name='yamcs.protobuf.mdb.CommandContainerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CommandContainerInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.CommandContainerInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CommandContainerInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CommandContainerInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.CommandContainerInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.CommandContainerInfo.sizeInBits', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseContainer', full_name='yamcs.protobuf.mdb.CommandContainerInfo.baseContainer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.mdb.CommandContainerInfo.entry', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9136,
  serialized_end=9431,
)


_INDIRECTPARAMETERREFINFO = _descriptor.Descriptor(
  name='IndirectParameterRefInfo',
  full_name='yamcs.protobuf.mdb.IndirectParameterRefInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.IndirectParameterRefInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliasNamespace', full_name='yamcs.protobuf.mdb.IndirectParameterRefInfo.aliasNamespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9433,
  serialized_end=9537,
)


_CONTAINERINFO_ANCILLARYDATAENTRY = _descriptor.Descriptor(
  name='AncillaryDataEntry',
  full_name='yamcs.protobuf.mdb.ContainerInfo.AncillaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.ContainerInfo.AncillaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ContainerInfo.AncillaryDataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3547,
)

_CONTAINERINFO = _descriptor.Descriptor(
  name='ContainerInfo',
  full_name='yamcs.protobuf.mdb.ContainerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ContainerInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.ContainerInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ContainerInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ContainerInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ContainerInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxInterval', full_name='yamcs.protobuf.mdb.ContainerInfo.maxInterval', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.ContainerInfo.sizeInBits', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseContainer', full_name='yamcs.protobuf.mdb.ContainerInfo.baseContainer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restrictionCriteria', full_name='yamcs.protobuf.mdb.ContainerInfo.restrictionCriteria', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restrictionCriteriaExpression', full_name='yamcs.protobuf.mdb.ContainerInfo.restrictionCriteriaExpression', index=9,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.mdb.ContainerInfo.entry', index=10,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedBy', full_name='yamcs.protobuf.mdb.ContainerInfo.usedBy', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ancillaryData', full_name='yamcs.protobuf.mdb.ContainerInfo.ancillaryData', index=12,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archivePartition', full_name='yamcs.protobuf.mdb.ContainerInfo.archivePartition', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINERINFO_ANCILLARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9540,
  serialized_end=10194,
)


_INPUTPARAMETERINFO = _descriptor.Descriptor(
  name='InputParameterInfo',
  full_name='yamcs.protobuf.mdb.InputParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.InputParameterInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputName', full_name='yamcs.protobuf.mdb.InputParameterInfo.inputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterInstance', full_name='yamcs.protobuf.mdb.InputParameterInfo.parameterInstance', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mandatory', full_name='yamcs.protobuf.mdb.InputParameterInfo.mandatory', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.InputParameterInfo.argument', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10197,
  serialized_end=10388,
)


_OUTPUTPARAMETERINFO = _descriptor.Descriptor(
  name='OutputParameterInfo',
  full_name='yamcs.protobuf.mdb.OutputParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.OutputParameterInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='yamcs.protobuf.mdb.OutputParameterInfo.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10390,
  serialized_end=10485,
)


_MATHELEMENT = _descriptor.Descriptor(
  name='MathElement',
  full_name='yamcs.protobuf.mdb.MathElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.MathElement.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='yamcs.protobuf.mdb.MathElement.operator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.MathElement.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.MathElement.parameter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterInstance', full_name='yamcs.protobuf.mdb.MathElement.parameterInstance', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MATHELEMENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10488,
  serialized_end=10751,
)


_ALGORITHMINFO = _descriptor.Descriptor(
  name='AlgorithmInfo',
  full_name='yamcs.protobuf.mdb.AlgorithmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.AlgorithmInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.AlgorithmInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.AlgorithmInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.AlgorithmInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.AlgorithmInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='yamcs.protobuf.mdb.AlgorithmInfo.scope', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.AlgorithmInfo.type', index=6,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='yamcs.protobuf.mdb.AlgorithmInfo.language', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='yamcs.protobuf.mdb.AlgorithmInfo.text', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputParameter', full_name='yamcs.protobuf.mdb.AlgorithmInfo.inputParameter', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputParameter', full_name='yamcs.protobuf.mdb.AlgorithmInfo.outputParameter', index=10,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onParameterUpdate', full_name='yamcs.protobuf.mdb.AlgorithmInfo.onParameterUpdate', index=11,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onPeriodicRate', full_name='yamcs.protobuf.mdb.AlgorithmInfo.onPeriodicRate', index=12,
      number=12, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mathElements', full_name='yamcs.protobuf.mdb.AlgorithmInfo.mathElements', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALGORITHMINFO_TYPE,
    _ALGORITHMINFO_SCOPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10754,
  serialized_end=11419,
)


_LISTSPACESYSTEMSREQUEST = _descriptor.Descriptor(
  name='ListSpaceSystemsRequest',
  full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest.next', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest.pos', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListSpaceSystemsRequest.limit', index=4,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11421,
  serialized_end=11517,
)


_LISTCONTAINERSREQUEST = _descriptor.Descriptor(
  name='ListContainersRequest',
  full_name='yamcs.protobuf.mdb.ListContainersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListContainersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListContainersRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system', full_name='yamcs.protobuf.mdb.ListContainersRequest.system', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListContainersRequest.next', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListContainersRequest.pos', index=4,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListContainersRequest.limit', index=5,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11519,
  serialized_end=11629,
)


_LISTPARAMETERTYPESREQUEST = _descriptor.Descriptor(
  name='ListParameterTypesRequest',
  full_name='yamcs.protobuf.mdb.ListParameterTypesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.system', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.next', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.pos', index=4,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListParameterTypesRequest.limit', index=5,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11631,
  serialized_end=11745,
)


_LISTALGORITHMSREQUEST = _descriptor.Descriptor(
  name='ListAlgorithmsRequest',
  full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.system', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.next', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.pos', index=4,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.limit', index=5,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='yamcs.protobuf.mdb.ListAlgorithmsRequest.scope', index=6,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11748,
  serialized_end=11914,
)


_LISTCOMMANDSREQUEST = _descriptor.Descriptor(
  name='ListCommandsRequest',
  full_name='yamcs.protobuf.mdb.ListCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListCommandsRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system', full_name='yamcs.protobuf.mdb.ListCommandsRequest.system', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='yamcs.protobuf.mdb.ListCommandsRequest.details', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListCommandsRequest.next', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListCommandsRequest.pos', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListCommandsRequest.limit', index=6,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noAbstract', full_name='yamcs.protobuf.mdb.ListCommandsRequest.noAbstract', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11917,
  serialized_end=12062,
)


_GETPARAMETERREQUEST = _descriptor.Descriptor(
  name='GetParameterRequest',
  full_name='yamcs.protobuf.mdb.GetParameterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetParameterRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetParameterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12064,
  serialized_end=12117,
)


_LISTPARAMETERSREQUEST = _descriptor.Descriptor(
  name='ListParametersRequest',
  full_name='yamcs.protobuf.mdb.ListParametersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ListParametersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.mdb.ListParametersRequest.q', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchMembers', full_name='yamcs.protobuf.mdb.ListParametersRequest.searchMembers', index=2,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='yamcs.protobuf.mdb.ListParametersRequest.details', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ListParametersRequest.type', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.mdb.ListParametersRequest.source', index=5,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system', full_name='yamcs.protobuf.mdb.ListParametersRequest.system', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.mdb.ListParametersRequest.next', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.mdb.ListParametersRequest.pos', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.mdb.ListParametersRequest.limit', index=9,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12120,
  serialized_end=12336,
)


_LISTPARAMETERSRESPONSE = _descriptor.Descriptor(
  name='ListParametersResponse',
  full_name='yamcs.protobuf.mdb.ListParametersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systems', full_name='yamcs.protobuf.mdb.ListParametersResponse.systems', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListParametersResponse.spaceSystems', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yamcs.protobuf.mdb.ListParametersResponse.parameters', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListParametersResponse.continuationToken', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListParametersResponse.totalSize', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12339,
  serialized_end=12544,
)


_BATCHGETPARAMETERSREQUEST = _descriptor.Descriptor(
  name='BatchGetParametersRequest',
  full_name='yamcs.protobuf.mdb.BatchGetParametersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.BatchGetParametersRequest.instance', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.mdb.BatchGetParametersRequest.id', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12546,
  serialized_end=12634,
)


_BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE = _descriptor.Descriptor(
  name='GetParameterResponse',
  full_name='yamcs.protobuf.mdb.BatchGetParametersResponse.GetParameterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.mdb.BatchGetParametersResponse.GetParameterResponse.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.BatchGetParametersResponse.GetParameterResponse.parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12754,
  serialized_end=12873,
)

_BATCHGETPARAMETERSRESPONSE = _descriptor.Descriptor(
  name='BatchGetParametersResponse',
  full_name='yamcs.protobuf.mdb.BatchGetParametersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='yamcs.protobuf.mdb.BatchGetParametersResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12637,
  serialized_end=12873,
)


_LISTCONTAINERSRESPONSE = _descriptor.Descriptor(
  name='ListContainersResponse',
  full_name='yamcs.protobuf.mdb.ListContainersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systems', full_name='yamcs.protobuf.mdb.ListContainersResponse.systems', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListContainersResponse.spaceSystems', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containers', full_name='yamcs.protobuf.mdb.ListContainersResponse.containers', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListContainersResponse.continuationToken', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListContainersResponse.totalSize', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12876,
  serialized_end=13081,
)


_LISTPARAMETERTYPESRESPONSE = _descriptor.Descriptor(
  name='ListParameterTypesResponse',
  full_name='yamcs.protobuf.mdb.ListParameterTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systems', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.systems', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.spaceSystems', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterTypes', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.parameterTypes', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.continuationToken', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.totalSize', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13084,
  serialized_end=13301,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.mdb.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systems', full_name='yamcs.protobuf.mdb.ListCommandsResponse.systems', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListCommandsResponse.spaceSystems', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commands', full_name='yamcs.protobuf.mdb.ListCommandsResponse.commands', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListCommandsResponse.continuationToken', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListCommandsResponse.totalSize', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13304,
  serialized_end=13503,
)


_LISTALGORITHMSRESPONSE = _descriptor.Descriptor(
  name='ListAlgorithmsResponse',
  full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systems', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.systems', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.spaceSystems', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithms', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.algorithms', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.continuationToken', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.totalSize', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13506,
  serialized_end=13711,
)


_GETALGORITHMREQUEST = _descriptor.Descriptor(
  name='GetAlgorithmRequest',
  full_name='yamcs.protobuf.mdb.GetAlgorithmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetAlgorithmRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetAlgorithmRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13713,
  serialized_end=13766,
)


_CREATEPARAMETERREQUEST_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.mdb.CreateParameterRequest.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.CreateParameterRequest.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.CreateParameterRequest.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14031,
  serialized_end=14077,
)

_CREATEPARAMETERREQUEST = _descriptor.Descriptor(
  name='CreateParameterRequest',
  full_name='yamcs.protobuf.mdb.CreateParameterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.CreateParameterRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CreateParameterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CreateParameterRequest.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CreateParameterRequest.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.mdb.CreateParameterRequest.aliases', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSource', full_name='yamcs.protobuf.mdb.CreateParameterRequest.dataSource', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterType', full_name='yamcs.protobuf.mdb.CreateParameterRequest.parameterType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEPARAMETERREQUEST_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13769,
  serialized_end=14077,
)


_CREATEPARAMETERTYPEREQUEST_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14031,
  serialized_end=14077,
)

_CREATEPARAMETERTYPEREQUEST = _descriptor.Descriptor(
  name='CreateParameterTypeRequest',
  full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.aliases', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.engType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.unit', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.signed', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.defaultAlarm', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarms', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.contextAlarms', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumerationValues', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.enumerationValues', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zeroStringValue', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.zeroStringValue', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oneStringValue', full_name='yamcs.protobuf.mdb.CreateParameterTypeRequest.oneStringValue', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEPARAMETERTYPEREQUEST_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14080,
  serialized_end=14585,
)


_GETMISSIONDATABASEREQUEST = _descriptor.Descriptor(
  name='GetMissionDatabaseRequest',
  full_name='yamcs.protobuf.mdb.GetMissionDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetMissionDatabaseRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14587,
  serialized_end=14632,
)


_EXPORTJAVAMISSIONDATABASEREQUEST = _descriptor.Descriptor(
  name='ExportJavaMissionDatabaseRequest',
  full_name='yamcs.protobuf.mdb.ExportJavaMissionDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ExportJavaMissionDatabaseRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14634,
  serialized_end=14686,
)


_STREAMMISSIONDATABASEREQUEST = _descriptor.Descriptor(
  name='StreamMissionDatabaseRequest',
  full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeSpaceSystems', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeSpaceSystems', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeContainers', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeContainers', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeParameters', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeParameters', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeParameterTypes', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeParameterTypes', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeCommands', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeCommands', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeAlgorithms', full_name='yamcs.protobuf.mdb.StreamMissionDatabaseRequest.includeAlgorithms', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14689,
  serialized_end=14903,
)


_MISSIONDATABASEITEM = _descriptor.Descriptor(
  name='MissionDatabaseItem',
  full_name='yamcs.protobuf.mdb.MissionDatabaseItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spaceSystem', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.spaceSystem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.parameter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterType', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.parameterType', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.command', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.algorithm', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='item', full_name='yamcs.protobuf.mdb.MissionDatabaseItem.item',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=14906,
  serialized_end=15279,
)


_LISTSPACESYSTEMSRESPONSE = _descriptor.Descriptor(
  name='ListSpaceSystemsResponse',
  full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spaceSystems', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.spaceSystems', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15282,
  serialized_end=15413,
)


_GETSPACESYSTEMREQUEST = _descriptor.Descriptor(
  name='GetSpaceSystemRequest',
  full_name='yamcs.protobuf.mdb.GetSpaceSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetSpaceSystemRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetSpaceSystemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15415,
  serialized_end=15470,
)


_EXPORTXTCEREQUEST = _descriptor.Descriptor(
  name='ExportXtceRequest',
  full_name='yamcs.protobuf.mdb.ExportXtceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.ExportXtceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ExportXtceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15472,
  serialized_end=15523,
)


_GETCOMMANDREQUEST = _descriptor.Descriptor(
  name='GetCommandRequest',
  full_name='yamcs.protobuf.mdb.GetCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.mdb.GetCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.GetCommandRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15525,
  serialized_end=15576,
)


_SPACESYSTEMINFO_ANCILLARYDATAENTRY = _descriptor.Descriptor(
  name='AncillaryDataEntry',
  full_name='yamcs.protobuf.mdb.SpaceSystemInfo.AncillaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.AncillaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.AncillaryDataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3547,
)

_SPACESYSTEMINFO = _descriptor.Descriptor(
  name='SpaceSystemInfo',
  full_name='yamcs.protobuf.mdb.SpaceSystemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.alias', index=4,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.version', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='history', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.history', index=6,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.sub', index=7,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ancillaryData', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.ancillaryData', index=8,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPACESYSTEMINFO_ANCILLARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15579,
  serialized_end=16019,
)

_MISSIONDATABASE.fields_by_name['spaceSystem'].message_type = _SPACESYSTEMINFO
_MISSIONDATABASE.fields_by_name['spaceSystems'].message_type = _SPACESYSTEMINFO
_ALARMRANGE.fields_by_name['level'].enum_type = _ALARMLEVELTYPE
_ENUMERATIONALARM.fields_by_name['level'].enum_type = _ALARMLEVELTYPE
_ALARMINFO.fields_by_name['staticAlarmRange'].message_type = _ALARMRANGE
_ALARMINFO.fields_by_name['staticAlarmRanges'].message_type = _ALARMRANGE
_ALARMINFO.fields_by_name['enumerationAlarm'].message_type = _ENUMERATIONALARM
_ALARMINFO.fields_by_name['enumerationAlarms'].message_type = _ENUMERATIONALARM
_CONTEXTALARMINFO.fields_by_name['comparison'].message_type = _COMPARISONINFO
_CONTEXTALARMINFO.fields_by_name['alarm'].message_type = _ALARMINFO
_DATAENCODINGINFO.fields_by_name['type'].enum_type = _DATAENCODINGINFO_TYPE
_DATAENCODINGINFO.fields_by_name['defaultCalibrator'].message_type = _CALIBRATORINFO
_DATAENCODINGINFO.fields_by_name['contextCalibrator'].message_type = _CONTEXTCALIBRATORINFO
_DATAENCODINGINFO.fields_by_name['contextCalibrators'].message_type = _CONTEXTCALIBRATORINFO
_DATAENCODINGINFO_TYPE.containing_type = _DATAENCODINGINFO
_CONTEXTCALIBRATORINFO.fields_by_name['comparison'].message_type = _COMPARISONINFO
_CONTEXTCALIBRATORINFO.fields_by_name['calibrator'].message_type = _CALIBRATORINFO
_CALIBRATORINFO.fields_by_name['polynomialCalibrator'].message_type = _POLYNOMIALCALIBRATORINFO
_CALIBRATORINFO.fields_by_name['splineCalibrator'].message_type = _SPLINECALIBRATORINFO
_CALIBRATORINFO.fields_by_name['javaExpressionCalibrator'].message_type = _JAVAEXPRESSIONCALIBRATORINFO
_CALIBRATORINFO.fields_by_name['type'].enum_type = _CALIBRATORINFO_TYPE
_CALIBRATORINFO_TYPE.containing_type = _CALIBRATORINFO
_SPLINECALIBRATORINFO_SPLINEPOINTINFO.containing_type = _SPLINECALIBRATORINFO
_SPLINECALIBRATORINFO.fields_by_name['point'].message_type = _SPLINECALIBRATORINFO_SPLINEPOINTINFO
_SPLINECALIBRATORINFO.fields_by_name['points'].message_type = _SPLINECALIBRATORINFO_SPLINEPOINTINFO
_PARAMETERTYPEINFO_ANCILLARYDATAENTRY.fields_by_name['value'].message_type = _ANCILLARYDATAINFO
_PARAMETERTYPEINFO_ANCILLARYDATAENTRY.containing_type = _PARAMETERTYPEINFO
_PARAMETERTYPEINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_PARAMETERTYPEINFO.fields_by_name['dataEncoding'].message_type = _DATAENCODINGINFO
_PARAMETERTYPEINFO.fields_by_name['unitSet'].message_type = _UNITINFO
_PARAMETERTYPEINFO.fields_by_name['defaultAlarm'].message_type = _ALARMINFO
_PARAMETERTYPEINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_PARAMETERTYPEINFO.fields_by_name['absoluteTimeInfo'].message_type = _ABSOLUTETIMEINFO
_PARAMETERTYPEINFO.fields_by_name['contextAlarm'].message_type = _CONTEXTALARMINFO
_PARAMETERTYPEINFO.fields_by_name['member'].message_type = _MEMBERINFO
_PARAMETERTYPEINFO.fields_by_name['arrayInfo'].message_type = _ARRAYINFO
_PARAMETERTYPEINFO.fields_by_name['ancillaryData'].message_type = _PARAMETERTYPEINFO_ANCILLARYDATAENTRY
_PARAMETERTYPEINFO.fields_by_name['numberFormat'].message_type = _NUMBERFORMATTYPEINFO
_PARAMETERTYPEINFO.fields_by_name['usedBy'].message_type = _PARAMETERINFO
_ABSOLUTETIMEINFO.fields_by_name['offsetFrom'].message_type = _PARAMETERINFO
_MEMBERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_MEMBERINFO.fields_by_name['type'].message_type = _PARAMETERTYPEINFO
_ARGUMENTMEMBERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_ARGUMENTMEMBERINFO.fields_by_name['type'].message_type = _ARGUMENTTYPEINFO
_PARAMETERDIMENSIONINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_ARRAYINFO.fields_by_name['type'].message_type = _PARAMETERTYPEINFO
_ARRAYINFO.fields_by_name['dimensions'].message_type = _PARAMETERDIMENSIONINFO
_USEDBYINFO.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_USEDBYINFO.fields_by_name['container'].message_type = _CONTAINERINFO
_PARAMETERINFO_ANCILLARYDATAENTRY.fields_by_name['value'].message_type = _ANCILLARYDATAINFO
_PARAMETERINFO_ANCILLARYDATAENTRY.containing_type = _PARAMETERINFO
_PARAMETERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_PARAMETERINFO.fields_by_name['type'].message_type = _PARAMETERTYPEINFO
_PARAMETERINFO.fields_by_name['dataSource'].enum_type = _DATASOURCETYPE
_PARAMETERINFO.fields_by_name['usedBy'].message_type = _USEDBYINFO
_PARAMETERINFO.fields_by_name['ancillaryData'].message_type = _PARAMETERINFO_ANCILLARYDATAENTRY
_ARGUMENTTYPEINFO.fields_by_name['dataEncoding'].message_type = _DATAENCODINGINFO
_ARGUMENTTYPEINFO.fields_by_name['unitSet'].message_type = _UNITINFO
_ARGUMENTTYPEINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_ARGUMENTTYPEINFO.fields_by_name['member'].message_type = _ARGUMENTMEMBERINFO
_ARGUMENTTYPEINFO.fields_by_name['dimensions'].message_type = _ARGUMENTDIMENSIONINFO
_ARGUMENTTYPEINFO.fields_by_name['elementType'].message_type = _ARGUMENTTYPEINFO
_ARGUMENTDIMENSIONINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_ARGUMENTINFO.fields_by_name['type'].message_type = _ARGUMENTTYPEINFO
_SIGNIFICANCEINFO.fields_by_name['consequenceLevel'].enum_type = _SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE.containing_type = _SIGNIFICANCEINFO
_COMPARISONINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_COMPARISONINFO.fields_by_name['operator'].enum_type = _COMPARISONINFO_OPERATORTYPE
_COMPARISONINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_COMPARISONINFO_OPERATORTYPE.containing_type = _COMPARISONINFO
_COMMANDINFO_ANCILLARYDATAENTRY.fields_by_name['value'].message_type = _ANCILLARYDATAINFO
_COMMANDINFO_ANCILLARYDATAENTRY.containing_type = _COMMANDINFO
_COMMANDINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_COMMANDINFO.fields_by_name['baseCommand'].message_type = _COMMANDINFO
_COMMANDINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_COMMANDINFO.fields_by_name['argumentAssignment'].message_type = _ARGUMENTASSIGNMENTINFO
_COMMANDINFO.fields_by_name['significance'].message_type = _SIGNIFICANCEINFO
_COMMANDINFO.fields_by_name['constraint'].message_type = _TRANSMISSIONCONSTRAINTINFO
_COMMANDINFO.fields_by_name['commandContainer'].message_type = _COMMANDCONTAINERINFO
_COMMANDINFO.fields_by_name['verifier'].message_type = _VERIFIERINFO
_COMMANDINFO.fields_by_name['ancillaryData'].message_type = _COMMANDINFO_ANCILLARYDATAENTRY
_COMMANDINFO.fields_by_name['effectiveSignificance'].message_type = _SIGNIFICANCEINFO
_VERIFIERINFO.fields_by_name['container'].message_type = _CONTAINERINFO
_VERIFIERINFO.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_VERIFIERINFO.fields_by_name['onSuccess'].enum_type = _VERIFIERINFO_TERMINATIONACTIONTYPE
_VERIFIERINFO.fields_by_name['onFail'].enum_type = _VERIFIERINFO_TERMINATIONACTIONTYPE
_VERIFIERINFO.fields_by_name['onTimeout'].enum_type = _VERIFIERINFO_TERMINATIONACTIONTYPE
_VERIFIERINFO.fields_by_name['checkWindow'].message_type = _CHECKWINDOWINFO
_VERIFIERINFO_TERMINATIONACTIONTYPE.containing_type = _VERIFIERINFO
_REPEATINFO.fields_by_name['dynamicCount'].message_type = _PARAMETERINFO
_SEQUENCEENTRYINFO.fields_by_name['referenceLocation'].enum_type = _SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE
_SEQUENCEENTRYINFO.fields_by_name['container'].message_type = _CONTAINERINFO
_SEQUENCEENTRYINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_SEQUENCEENTRYINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_SEQUENCEENTRYINFO.fields_by_name['fixedValue'].message_type = _FIXEDVALUEINFO
_SEQUENCEENTRYINFO.fields_by_name['repeat'].message_type = _REPEATINFO
_SEQUENCEENTRYINFO.fields_by_name['indirectParameterRef'].message_type = _INDIRECTPARAMETERREFINFO
_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE.containing_type = _SEQUENCEENTRYINFO
_COMMANDCONTAINERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_COMMANDCONTAINERINFO.fields_by_name['baseContainer'].message_type = _COMMANDCONTAINERINFO
_COMMANDCONTAINERINFO.fields_by_name['entry'].message_type = _SEQUENCEENTRYINFO
_INDIRECTPARAMETERREFINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_CONTAINERINFO_ANCILLARYDATAENTRY.fields_by_name['value'].message_type = _ANCILLARYDATAINFO
_CONTAINERINFO_ANCILLARYDATAENTRY.containing_type = _CONTAINERINFO
_CONTAINERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_CONTAINERINFO.fields_by_name['baseContainer'].message_type = _CONTAINERINFO
_CONTAINERINFO.fields_by_name['restrictionCriteria'].message_type = _COMPARISONINFO
_CONTAINERINFO.fields_by_name['entry'].message_type = _SEQUENCEENTRYINFO
_CONTAINERINFO.fields_by_name['usedBy'].message_type = _USEDBYINFO
_CONTAINERINFO.fields_by_name['ancillaryData'].message_type = _CONTAINERINFO_ANCILLARYDATAENTRY
_INPUTPARAMETERINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_INPUTPARAMETERINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_OUTPUTPARAMETERINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_MATHELEMENT.fields_by_name['type'].enum_type = _MATHELEMENT_TYPE
_MATHELEMENT.fields_by_name['parameter'].message_type = _PARAMETERINFO
_MATHELEMENT_TYPE.containing_type = _MATHELEMENT
_ALGORITHMINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_ALGORITHMINFO.fields_by_name['scope'].enum_type = _ALGORITHMINFO_SCOPE
_ALGORITHMINFO.fields_by_name['type'].enum_type = _ALGORITHMINFO_TYPE
_ALGORITHMINFO.fields_by_name['inputParameter'].message_type = _INPUTPARAMETERINFO
_ALGORITHMINFO.fields_by_name['outputParameter'].message_type = _OUTPUTPARAMETERINFO
_ALGORITHMINFO.fields_by_name['onParameterUpdate'].message_type = _PARAMETERINFO
_ALGORITHMINFO.fields_by_name['mathElements'].message_type = _MATHELEMENT
_ALGORITHMINFO_TYPE.containing_type = _ALGORITHMINFO
_ALGORITHMINFO_SCOPE.containing_type = _ALGORITHMINFO
_LISTALGORITHMSREQUEST.fields_by_name['scope'].enum_type = _ALGORITHMINFO_SCOPE
_LISTPARAMETERSREQUEST.fields_by_name['source'].enum_type = _DATASOURCETYPE
_LISTPARAMETERSRESPONSE.fields_by_name['systems'].message_type = _SPACESYSTEMINFO
_LISTPARAMETERSRESPONSE.fields_by_name['parameters'].message_type = _PARAMETERINFO
_BATCHGETPARAMETERSREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE.fields_by_name['parameter'].message_type = _PARAMETERINFO
_BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE.containing_type = _BATCHGETPARAMETERSRESPONSE
_BATCHGETPARAMETERSRESPONSE.fields_by_name['response'].message_type = _BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE
_LISTCONTAINERSRESPONSE.fields_by_name['systems'].message_type = _SPACESYSTEMINFO
_LISTCONTAINERSRESPONSE.fields_by_name['containers'].message_type = _CONTAINERINFO
_LISTPARAMETERTYPESRESPONSE.fields_by_name['systems'].message_type = _SPACESYSTEMINFO
_LISTPARAMETERTYPESRESPONSE.fields_by_name['parameterTypes'].message_type = _PARAMETERTYPEINFO
_LISTCOMMANDSRESPONSE.fields_by_name['systems'].message_type = _SPACESYSTEMINFO
_LISTCOMMANDSRESPONSE.fields_by_name['commands'].message_type = _COMMANDINFO
_LISTALGORITHMSRESPONSE.fields_by_name['systems'].message_type = _SPACESYSTEMINFO
_LISTALGORITHMSRESPONSE.fields_by_name['algorithms'].message_type = _ALGORITHMINFO
_CREATEPARAMETERREQUEST_ALIASESENTRY.containing_type = _CREATEPARAMETERREQUEST
_CREATEPARAMETERREQUEST.fields_by_name['aliases'].message_type = _CREATEPARAMETERREQUEST_ALIASESENTRY
_CREATEPARAMETERREQUEST.fields_by_name['dataSource'].enum_type = _DATASOURCETYPE
_CREATEPARAMETERTYPEREQUEST_ALIASESENTRY.containing_type = _CREATEPARAMETERTYPEREQUEST
_CREATEPARAMETERTYPEREQUEST.fields_by_name['aliases'].message_type = _CREATEPARAMETERTYPEREQUEST_ALIASESENTRY
_CREATEPARAMETERTYPEREQUEST.fields_by_name['defaultAlarm'].message_type = _ALARMINFO
_CREATEPARAMETERTYPEREQUEST.fields_by_name['contextAlarms'].message_type = _CONTEXTALARMINFO
_CREATEPARAMETERTYPEREQUEST.fields_by_name['enumerationValues'].message_type = _ENUMVALUE
_MISSIONDATABASEITEM.fields_by_name['spaceSystem'].message_type = _SPACESYSTEMINFO
_MISSIONDATABASEITEM.fields_by_name['container'].message_type = _CONTAINERINFO
_MISSIONDATABASEITEM.fields_by_name['parameter'].message_type = _PARAMETERINFO
_MISSIONDATABASEITEM.fields_by_name['parameterType'].message_type = _PARAMETERTYPEINFO
_MISSIONDATABASEITEM.fields_by_name['command'].message_type = _COMMANDINFO
_MISSIONDATABASEITEM.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['spaceSystem'])
_MISSIONDATABASEITEM.fields_by_name['spaceSystem'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['container'])
_MISSIONDATABASEITEM.fields_by_name['container'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['parameter'])
_MISSIONDATABASEITEM.fields_by_name['parameter'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['parameterType'])
_MISSIONDATABASEITEM.fields_by_name['parameterType'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['command'])
_MISSIONDATABASEITEM.fields_by_name['command'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_MISSIONDATABASEITEM.oneofs_by_name['item'].fields.append(
  _MISSIONDATABASEITEM.fields_by_name['algorithm'])
_MISSIONDATABASEITEM.fields_by_name['algorithm'].containing_oneof = _MISSIONDATABASEITEM.oneofs_by_name['item']
_LISTSPACESYSTEMSRESPONSE.fields_by_name['spaceSystems'].message_type = _SPACESYSTEMINFO
_SPACESYSTEMINFO_ANCILLARYDATAENTRY.fields_by_name['value'].message_type = _ANCILLARYDATAINFO
_SPACESYSTEMINFO_ANCILLARYDATAENTRY.containing_type = _SPACESYSTEMINFO
_SPACESYSTEMINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_SPACESYSTEMINFO.fields_by_name['history'].message_type = _HISTORYINFO
_SPACESYSTEMINFO.fields_by_name['sub'].message_type = _SPACESYSTEMINFO
_SPACESYSTEMINFO.fields_by_name['ancillaryData'].message_type = _SPACESYSTEMINFO_ANCILLARYDATAENTRY
DESCRIPTOR.message_types_by_name['MissionDatabase'] = _MISSIONDATABASE
DESCRIPTOR.message_types_by_name['HistoryInfo'] = _HISTORYINFO
DESCRIPTOR.message_types_by_name['UnitInfo'] = _UNITINFO
DESCRIPTOR.message_types_by_name['AlarmRange'] = _ALARMRANGE
DESCRIPTOR.message_types_by_name['EnumerationAlarm'] = _ENUMERATIONALARM
DESCRIPTOR.message_types_by_name['AlarmInfo'] = _ALARMINFO
DESCRIPTOR.message_types_by_name['ContextAlarmInfo'] = _CONTEXTALARMINFO
DESCRIPTOR.message_types_by_name['DataEncodingInfo'] = _DATAENCODINGINFO
DESCRIPTOR.message_types_by_name['ContextCalibratorInfo'] = _CONTEXTCALIBRATORINFO
DESCRIPTOR.message_types_by_name['CalibratorInfo'] = _CALIBRATORINFO
DESCRIPTOR.message_types_by_name['PolynomialCalibratorInfo'] = _POLYNOMIALCALIBRATORINFO
DESCRIPTOR.message_types_by_name['SplineCalibratorInfo'] = _SPLINECALIBRATORINFO
DESCRIPTOR.message_types_by_name['JavaExpressionCalibratorInfo'] = _JAVAEXPRESSIONCALIBRATORINFO
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['ParameterTypeInfo'] = _PARAMETERTYPEINFO
DESCRIPTOR.message_types_by_name['NumberFormatTypeInfo'] = _NUMBERFORMATTYPEINFO
DESCRIPTOR.message_types_by_name['GetContainerRequest'] = _GETCONTAINERREQUEST
DESCRIPTOR.message_types_by_name['GetParameterTypeRequest'] = _GETPARAMETERTYPEREQUEST
DESCRIPTOR.message_types_by_name['AbsoluteTimeInfo'] = _ABSOLUTETIMEINFO
DESCRIPTOR.message_types_by_name['MemberInfo'] = _MEMBERINFO
DESCRIPTOR.message_types_by_name['ArgumentMemberInfo'] = _ARGUMENTMEMBERINFO
DESCRIPTOR.message_types_by_name['ParameterDimensionInfo'] = _PARAMETERDIMENSIONINFO
DESCRIPTOR.message_types_by_name['ArrayInfo'] = _ARRAYINFO
DESCRIPTOR.message_types_by_name['UsedByInfo'] = _USEDBYINFO
DESCRIPTOR.message_types_by_name['ParameterInfo'] = _PARAMETERINFO
DESCRIPTOR.message_types_by_name['AncillaryDataInfo'] = _ANCILLARYDATAINFO
DESCRIPTOR.message_types_by_name['ArgumentTypeInfo'] = _ARGUMENTTYPEINFO
DESCRIPTOR.message_types_by_name['ArgumentDimensionInfo'] = _ARGUMENTDIMENSIONINFO
DESCRIPTOR.message_types_by_name['ArgumentInfo'] = _ARGUMENTINFO
DESCRIPTOR.message_types_by_name['ArgumentAssignmentInfo'] = _ARGUMENTASSIGNMENTINFO
DESCRIPTOR.message_types_by_name['SignificanceInfo'] = _SIGNIFICANCEINFO
DESCRIPTOR.message_types_by_name['ComparisonInfo'] = _COMPARISONINFO
DESCRIPTOR.message_types_by_name['TransmissionConstraintInfo'] = _TRANSMISSIONCONSTRAINTINFO
DESCRIPTOR.message_types_by_name['CommandInfo'] = _COMMANDINFO
DESCRIPTOR.message_types_by_name['VerifierInfo'] = _VERIFIERINFO
DESCRIPTOR.message_types_by_name['CheckWindowInfo'] = _CHECKWINDOWINFO
DESCRIPTOR.message_types_by_name['RepeatInfo'] = _REPEATINFO
DESCRIPTOR.message_types_by_name['SequenceEntryInfo'] = _SEQUENCEENTRYINFO
DESCRIPTOR.message_types_by_name['FixedValueInfo'] = _FIXEDVALUEINFO
DESCRIPTOR.message_types_by_name['CommandContainerInfo'] = _COMMANDCONTAINERINFO
DESCRIPTOR.message_types_by_name['IndirectParameterRefInfo'] = _INDIRECTPARAMETERREFINFO
DESCRIPTOR.message_types_by_name['ContainerInfo'] = _CONTAINERINFO
DESCRIPTOR.message_types_by_name['InputParameterInfo'] = _INPUTPARAMETERINFO
DESCRIPTOR.message_types_by_name['OutputParameterInfo'] = _OUTPUTPARAMETERINFO
DESCRIPTOR.message_types_by_name['MathElement'] = _MATHELEMENT
DESCRIPTOR.message_types_by_name['AlgorithmInfo'] = _ALGORITHMINFO
DESCRIPTOR.message_types_by_name['ListSpaceSystemsRequest'] = _LISTSPACESYSTEMSREQUEST
DESCRIPTOR.message_types_by_name['ListContainersRequest'] = _LISTCONTAINERSREQUEST
DESCRIPTOR.message_types_by_name['ListParameterTypesRequest'] = _LISTPARAMETERTYPESREQUEST
DESCRIPTOR.message_types_by_name['ListAlgorithmsRequest'] = _LISTALGORITHMSREQUEST
DESCRIPTOR.message_types_by_name['ListCommandsRequest'] = _LISTCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['GetParameterRequest'] = _GETPARAMETERREQUEST
DESCRIPTOR.message_types_by_name['ListParametersRequest'] = _LISTPARAMETERSREQUEST
DESCRIPTOR.message_types_by_name['ListParametersResponse'] = _LISTPARAMETERSRESPONSE
DESCRIPTOR.message_types_by_name['BatchGetParametersRequest'] = _BATCHGETPARAMETERSREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParametersResponse'] = _BATCHGETPARAMETERSRESPONSE
DESCRIPTOR.message_types_by_name['ListContainersResponse'] = _LISTCONTAINERSRESPONSE
DESCRIPTOR.message_types_by_name['ListParameterTypesResponse'] = _LISTPARAMETERTYPESRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['ListAlgorithmsResponse'] = _LISTALGORITHMSRESPONSE
DESCRIPTOR.message_types_by_name['GetAlgorithmRequest'] = _GETALGORITHMREQUEST
DESCRIPTOR.message_types_by_name['CreateParameterRequest'] = _CREATEPARAMETERREQUEST
DESCRIPTOR.message_types_by_name['CreateParameterTypeRequest'] = _CREATEPARAMETERTYPEREQUEST
DESCRIPTOR.message_types_by_name['GetMissionDatabaseRequest'] = _GETMISSIONDATABASEREQUEST
DESCRIPTOR.message_types_by_name['ExportJavaMissionDatabaseRequest'] = _EXPORTJAVAMISSIONDATABASEREQUEST
DESCRIPTOR.message_types_by_name['StreamMissionDatabaseRequest'] = _STREAMMISSIONDATABASEREQUEST
DESCRIPTOR.message_types_by_name['MissionDatabaseItem'] = _MISSIONDATABASEITEM
DESCRIPTOR.message_types_by_name['ListSpaceSystemsResponse'] = _LISTSPACESYSTEMSRESPONSE
DESCRIPTOR.message_types_by_name['GetSpaceSystemRequest'] = _GETSPACESYSTEMREQUEST
DESCRIPTOR.message_types_by_name['ExportXtceRequest'] = _EXPORTXTCEREQUEST
DESCRIPTOR.message_types_by_name['GetCommandRequest'] = _GETCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['SpaceSystemInfo'] = _SPACESYSTEMINFO
DESCRIPTOR.enum_types_by_name['DataSourceType'] = _DATASOURCETYPE
DESCRIPTOR.enum_types_by_name['AlarmLevelType'] = _ALARMLEVELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionDatabase = _reflection.GeneratedProtocolMessageType('MissionDatabase', (_message.Message,), {
  'DESCRIPTOR' : _MISSIONDATABASE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.MissionDatabase)
  })
_sym_db.RegisterMessage(MissionDatabase)

HistoryInfo = _reflection.GeneratedProtocolMessageType('HistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.HistoryInfo)
  })
_sym_db.RegisterMessage(HistoryInfo)

UnitInfo = _reflection.GeneratedProtocolMessageType('UnitInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNITINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.UnitInfo)
  })
_sym_db.RegisterMessage(UnitInfo)

AlarmRange = _reflection.GeneratedProtocolMessageType('AlarmRange', (_message.Message,), {
  'DESCRIPTOR' : _ALARMRANGE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlarmRange)
  })
_sym_db.RegisterMessage(AlarmRange)

EnumerationAlarm = _reflection.GeneratedProtocolMessageType('EnumerationAlarm', (_message.Message,), {
  'DESCRIPTOR' : _ENUMERATIONALARM,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.EnumerationAlarm)
  })
_sym_db.RegisterMessage(EnumerationAlarm)

AlarmInfo = _reflection.GeneratedProtocolMessageType('AlarmInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALARMINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlarmInfo)
  })
_sym_db.RegisterMessage(AlarmInfo)

ContextAlarmInfo = _reflection.GeneratedProtocolMessageType('ContextAlarmInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTEXTALARMINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContextAlarmInfo)
  })
_sym_db.RegisterMessage(ContextAlarmInfo)

DataEncodingInfo = _reflection.GeneratedProtocolMessageType('DataEncodingInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAENCODINGINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.DataEncodingInfo)
  })
_sym_db.RegisterMessage(DataEncodingInfo)

ContextCalibratorInfo = _reflection.GeneratedProtocolMessageType('ContextCalibratorInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTEXTCALIBRATORINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContextCalibratorInfo)
  })
_sym_db.RegisterMessage(ContextCalibratorInfo)

CalibratorInfo = _reflection.GeneratedProtocolMessageType('CalibratorInfo', (_message.Message,), {
  'DESCRIPTOR' : _CALIBRATORINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CalibratorInfo)
  })
_sym_db.RegisterMessage(CalibratorInfo)

PolynomialCalibratorInfo = _reflection.GeneratedProtocolMessageType('PolynomialCalibratorInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLYNOMIALCALIBRATORINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.PolynomialCalibratorInfo)
  })
_sym_db.RegisterMessage(PolynomialCalibratorInfo)

SplineCalibratorInfo = _reflection.GeneratedProtocolMessageType('SplineCalibratorInfo', (_message.Message,), {

  'SplinePointInfo' : _reflection.GeneratedProtocolMessageType('SplinePointInfo', (_message.Message,), {
    'DESCRIPTOR' : _SPLINECALIBRATORINFO_SPLINEPOINTINFO,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo)
    })
  ,
  'DESCRIPTOR' : _SPLINECALIBRATORINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SplineCalibratorInfo)
  })
_sym_db.RegisterMessage(SplineCalibratorInfo)
_sym_db.RegisterMessage(SplineCalibratorInfo.SplinePointInfo)

JavaExpressionCalibratorInfo = _reflection.GeneratedProtocolMessageType('JavaExpressionCalibratorInfo', (_message.Message,), {
  'DESCRIPTOR' : _JAVAEXPRESSIONCALIBRATORINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.JavaExpressionCalibratorInfo)
  })
_sym_db.RegisterMessage(JavaExpressionCalibratorInfo)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), {
  'DESCRIPTOR' : _ENUMVALUE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.EnumValue)
  })
_sym_db.RegisterMessage(EnumValue)

ParameterTypeInfo = _reflection.GeneratedProtocolMessageType('ParameterTypeInfo', (_message.Message,), {

  'AncillaryDataEntry' : _reflection.GeneratedProtocolMessageType('AncillaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PARAMETERTYPEINFO_ANCILLARYDATAENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterTypeInfo.AncillaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _PARAMETERTYPEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterTypeInfo)
  })
_sym_db.RegisterMessage(ParameterTypeInfo)
_sym_db.RegisterMessage(ParameterTypeInfo.AncillaryDataEntry)

NumberFormatTypeInfo = _reflection.GeneratedProtocolMessageType('NumberFormatTypeInfo', (_message.Message,), {
  'DESCRIPTOR' : _NUMBERFORMATTYPEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.NumberFormatTypeInfo)
  })
_sym_db.RegisterMessage(NumberFormatTypeInfo)

GetContainerRequest = _reflection.GeneratedProtocolMessageType('GetContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetContainerRequest)
  })
_sym_db.RegisterMessage(GetContainerRequest)

GetParameterTypeRequest = _reflection.GeneratedProtocolMessageType('GetParameterTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERTYPEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetParameterTypeRequest)
  })
_sym_db.RegisterMessage(GetParameterTypeRequest)

AbsoluteTimeInfo = _reflection.GeneratedProtocolMessageType('AbsoluteTimeInfo', (_message.Message,), {
  'DESCRIPTOR' : _ABSOLUTETIMEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AbsoluteTimeInfo)
  })
_sym_db.RegisterMessage(AbsoluteTimeInfo)

MemberInfo = _reflection.GeneratedProtocolMessageType('MemberInfo', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.MemberInfo)
  })
_sym_db.RegisterMessage(MemberInfo)

ArgumentMemberInfo = _reflection.GeneratedProtocolMessageType('ArgumentMemberInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENTMEMBERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentMemberInfo)
  })
_sym_db.RegisterMessage(ArgumentMemberInfo)

ParameterDimensionInfo = _reflection.GeneratedProtocolMessageType('ParameterDimensionInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERDIMENSIONINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterDimensionInfo)
  })
_sym_db.RegisterMessage(ParameterDimensionInfo)

ArrayInfo = _reflection.GeneratedProtocolMessageType('ArrayInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArrayInfo)
  })
_sym_db.RegisterMessage(ArrayInfo)

UsedByInfo = _reflection.GeneratedProtocolMessageType('UsedByInfo', (_message.Message,), {
  'DESCRIPTOR' : _USEDBYINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.UsedByInfo)
  })
_sym_db.RegisterMessage(UsedByInfo)

ParameterInfo = _reflection.GeneratedProtocolMessageType('ParameterInfo', (_message.Message,), {

  'AncillaryDataEntry' : _reflection.GeneratedProtocolMessageType('AncillaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PARAMETERINFO_ANCILLARYDATAENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterInfo.AncillaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _PARAMETERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterInfo)
  })
_sym_db.RegisterMessage(ParameterInfo)
_sym_db.RegisterMessage(ParameterInfo.AncillaryDataEntry)

AncillaryDataInfo = _reflection.GeneratedProtocolMessageType('AncillaryDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _ANCILLARYDATAINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AncillaryDataInfo)
  })
_sym_db.RegisterMessage(AncillaryDataInfo)

ArgumentTypeInfo = _reflection.GeneratedProtocolMessageType('ArgumentTypeInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENTTYPEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentTypeInfo)
  })
_sym_db.RegisterMessage(ArgumentTypeInfo)

ArgumentDimensionInfo = _reflection.GeneratedProtocolMessageType('ArgumentDimensionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENTDIMENSIONINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentDimensionInfo)
  })
_sym_db.RegisterMessage(ArgumentDimensionInfo)

ArgumentInfo = _reflection.GeneratedProtocolMessageType('ArgumentInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENTINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentInfo)
  })
_sym_db.RegisterMessage(ArgumentInfo)

ArgumentAssignmentInfo = _reflection.GeneratedProtocolMessageType('ArgumentAssignmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENTASSIGNMENTINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentAssignmentInfo)
  })
_sym_db.RegisterMessage(ArgumentAssignmentInfo)

SignificanceInfo = _reflection.GeneratedProtocolMessageType('SignificanceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNIFICANCEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SignificanceInfo)
  })
_sym_db.RegisterMessage(SignificanceInfo)

ComparisonInfo = _reflection.GeneratedProtocolMessageType('ComparisonInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMPARISONINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ComparisonInfo)
  })
_sym_db.RegisterMessage(ComparisonInfo)

TransmissionConstraintInfo = _reflection.GeneratedProtocolMessageType('TransmissionConstraintInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONCONSTRAINTINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.TransmissionConstraintInfo)
  })
_sym_db.RegisterMessage(TransmissionConstraintInfo)

CommandInfo = _reflection.GeneratedProtocolMessageType('CommandInfo', (_message.Message,), {

  'AncillaryDataEntry' : _reflection.GeneratedProtocolMessageType('AncillaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMANDINFO_ANCILLARYDATAENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CommandInfo.AncillaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _COMMANDINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CommandInfo)
  })
_sym_db.RegisterMessage(CommandInfo)
_sym_db.RegisterMessage(CommandInfo.AncillaryDataEntry)

VerifierInfo = _reflection.GeneratedProtocolMessageType('VerifierInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERIFIERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.VerifierInfo)
  })
_sym_db.RegisterMessage(VerifierInfo)

CheckWindowInfo = _reflection.GeneratedProtocolMessageType('CheckWindowInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHECKWINDOWINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CheckWindowInfo)
  })
_sym_db.RegisterMessage(CheckWindowInfo)

RepeatInfo = _reflection.GeneratedProtocolMessageType('RepeatInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPEATINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.RepeatInfo)
  })
_sym_db.RegisterMessage(RepeatInfo)

SequenceEntryInfo = _reflection.GeneratedProtocolMessageType('SequenceEntryInfo', (_message.Message,), {
  'DESCRIPTOR' : _SEQUENCEENTRYINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SequenceEntryInfo)
  })
_sym_db.RegisterMessage(SequenceEntryInfo)

FixedValueInfo = _reflection.GeneratedProtocolMessageType('FixedValueInfo', (_message.Message,), {
  'DESCRIPTOR' : _FIXEDVALUEINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.FixedValueInfo)
  })
_sym_db.RegisterMessage(FixedValueInfo)

CommandContainerInfo = _reflection.GeneratedProtocolMessageType('CommandContainerInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCONTAINERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CommandContainerInfo)
  })
_sym_db.RegisterMessage(CommandContainerInfo)

IndirectParameterRefInfo = _reflection.GeneratedProtocolMessageType('IndirectParameterRefInfo', (_message.Message,), {
  'DESCRIPTOR' : _INDIRECTPARAMETERREFINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.IndirectParameterRefInfo)
  })
_sym_db.RegisterMessage(IndirectParameterRefInfo)

ContainerInfo = _reflection.GeneratedProtocolMessageType('ContainerInfo', (_message.Message,), {

  'AncillaryDataEntry' : _reflection.GeneratedProtocolMessageType('AncillaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERINFO_ANCILLARYDATAENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContainerInfo.AncillaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContainerInfo)
  })
_sym_db.RegisterMessage(ContainerInfo)
_sym_db.RegisterMessage(ContainerInfo.AncillaryDataEntry)

InputParameterInfo = _reflection.GeneratedProtocolMessageType('InputParameterInfo', (_message.Message,), {
  'DESCRIPTOR' : _INPUTPARAMETERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.InputParameterInfo)
  })
_sym_db.RegisterMessage(InputParameterInfo)

OutputParameterInfo = _reflection.GeneratedProtocolMessageType('OutputParameterInfo', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTPARAMETERINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.OutputParameterInfo)
  })
_sym_db.RegisterMessage(OutputParameterInfo)

MathElement = _reflection.GeneratedProtocolMessageType('MathElement', (_message.Message,), {
  'DESCRIPTOR' : _MATHELEMENT,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.MathElement)
  })
_sym_db.RegisterMessage(MathElement)

AlgorithmInfo = _reflection.GeneratedProtocolMessageType('AlgorithmInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlgorithmInfo)
  })
_sym_db.RegisterMessage(AlgorithmInfo)

ListSpaceSystemsRequest = _reflection.GeneratedProtocolMessageType('ListSpaceSystemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSPACESYSTEMSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListSpaceSystemsRequest)
  })
_sym_db.RegisterMessage(ListSpaceSystemsRequest)

ListContainersRequest = _reflection.GeneratedProtocolMessageType('ListContainersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListContainersRequest)
  })
_sym_db.RegisterMessage(ListContainersRequest)

ListParameterTypesRequest = _reflection.GeneratedProtocolMessageType('ListParameterTypesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERTYPESREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParameterTypesRequest)
  })
_sym_db.RegisterMessage(ListParameterTypesRequest)

ListAlgorithmsRequest = _reflection.GeneratedProtocolMessageType('ListAlgorithmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALGORITHMSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListAlgorithmsRequest)
  })
_sym_db.RegisterMessage(ListAlgorithmsRequest)

ListCommandsRequest = _reflection.GeneratedProtocolMessageType('ListCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListCommandsRequest)
  })
_sym_db.RegisterMessage(ListCommandsRequest)

GetParameterRequest = _reflection.GeneratedProtocolMessageType('GetParameterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetParameterRequest)
  })
_sym_db.RegisterMessage(GetParameterRequest)

ListParametersRequest = _reflection.GeneratedProtocolMessageType('ListParametersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParametersRequest)
  })
_sym_db.RegisterMessage(ListParametersRequest)

ListParametersResponse = _reflection.GeneratedProtocolMessageType('ListParametersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParametersResponse)
  })
_sym_db.RegisterMessage(ListParametersResponse)

BatchGetParametersRequest = _reflection.GeneratedProtocolMessageType('BatchGetParametersRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERSREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BatchGetParametersRequest)
  })
_sym_db.RegisterMessage(BatchGetParametersRequest)

BatchGetParametersResponse = _reflection.GeneratedProtocolMessageType('BatchGetParametersResponse', (_message.Message,), {

  'GetParameterResponse' : _reflection.GeneratedProtocolMessageType('GetParameterResponse', (_message.Message,), {
    'DESCRIPTOR' : _BATCHGETPARAMETERSRESPONSE_GETPARAMETERRESPONSE,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BatchGetParametersResponse.GetParameterResponse)
    })
  ,
  'DESCRIPTOR' : _BATCHGETPARAMETERSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BatchGetParametersResponse)
  })
_sym_db.RegisterMessage(BatchGetParametersResponse)
_sym_db.RegisterMessage(BatchGetParametersResponse.GetParameterResponse)

ListContainersResponse = _reflection.GeneratedProtocolMessageType('ListContainersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListContainersResponse)
  })
_sym_db.RegisterMessage(ListContainersResponse)

ListParameterTypesResponse = _reflection.GeneratedProtocolMessageType('ListParameterTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERTYPESRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParameterTypesResponse)
  })
_sym_db.RegisterMessage(ListParameterTypesResponse)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListCommandsResponse)
  })
_sym_db.RegisterMessage(ListCommandsResponse)

ListAlgorithmsResponse = _reflection.GeneratedProtocolMessageType('ListAlgorithmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALGORITHMSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListAlgorithmsResponse)
  })
_sym_db.RegisterMessage(ListAlgorithmsResponse)

GetAlgorithmRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetAlgorithmRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmRequest)

CreateParameterRequest = _reflection.GeneratedProtocolMessageType('CreateParameterRequest', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEPARAMETERREQUEST_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CreateParameterRequest.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEPARAMETERREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CreateParameterRequest)
  })
_sym_db.RegisterMessage(CreateParameterRequest)
_sym_db.RegisterMessage(CreateParameterRequest.AliasesEntry)

CreateParameterTypeRequest = _reflection.GeneratedProtocolMessageType('CreateParameterTypeRequest', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEPARAMETERTYPEREQUEST_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CreateParameterTypeRequest.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEPARAMETERTYPEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CreateParameterTypeRequest)
  })
_sym_db.RegisterMessage(CreateParameterTypeRequest)
_sym_db.RegisterMessage(CreateParameterTypeRequest.AliasesEntry)

GetMissionDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetMissionDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMISSIONDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetMissionDatabaseRequest)
  })
_sym_db.RegisterMessage(GetMissionDatabaseRequest)

ExportJavaMissionDatabaseRequest = _reflection.GeneratedProtocolMessageType('ExportJavaMissionDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTJAVAMISSIONDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ExportJavaMissionDatabaseRequest)
  })
_sym_db.RegisterMessage(ExportJavaMissionDatabaseRequest)

StreamMissionDatabaseRequest = _reflection.GeneratedProtocolMessageType('StreamMissionDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMISSIONDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.StreamMissionDatabaseRequest)
  })
_sym_db.RegisterMessage(StreamMissionDatabaseRequest)

MissionDatabaseItem = _reflection.GeneratedProtocolMessageType('MissionDatabaseItem', (_message.Message,), {
  'DESCRIPTOR' : _MISSIONDATABASEITEM,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.MissionDatabaseItem)
  })
_sym_db.RegisterMessage(MissionDatabaseItem)

ListSpaceSystemsResponse = _reflection.GeneratedProtocolMessageType('ListSpaceSystemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSPACESYSTEMSRESPONSE,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListSpaceSystemsResponse)
  })
_sym_db.RegisterMessage(ListSpaceSystemsResponse)

GetSpaceSystemRequest = _reflection.GeneratedProtocolMessageType('GetSpaceSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSPACESYSTEMREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetSpaceSystemRequest)
  })
_sym_db.RegisterMessage(GetSpaceSystemRequest)

ExportXtceRequest = _reflection.GeneratedProtocolMessageType('ExportXtceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTXTCEREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ExportXtceRequest)
  })
_sym_db.RegisterMessage(ExportXtceRequest)

GetCommandRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.GetCommandRequest)
  })
_sym_db.RegisterMessage(GetCommandRequest)

SpaceSystemInfo = _reflection.GeneratedProtocolMessageType('SpaceSystemInfo', (_message.Message,), {

  'AncillaryDataEntry' : _reflection.GeneratedProtocolMessageType('AncillaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACESYSTEMINFO_ANCILLARYDATAENTRY,
    '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SpaceSystemInfo.AncillaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _SPACESYSTEMINFO,
  '__module__' : 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SpaceSystemInfo)
  })
_sym_db.RegisterMessage(SpaceSystemInfo)
_sym_db.RegisterMessage(SpaceSystemInfo.AncillaryDataEntry)


DESCRIPTOR._options = None
_MISSIONDATABASE.fields_by_name['spaceSystem']._options = None
_ALARMINFO.fields_by_name['staticAlarmRange']._options = None
_ALARMINFO.fields_by_name['enumerationAlarm']._options = None
_DATAENCODINGINFO.fields_by_name['contextCalibrator']._options = None
_POLYNOMIALCALIBRATORINFO.fields_by_name['coefficient']._options = None
_SPLINECALIBRATORINFO.fields_by_name['point']._options = None
_PARAMETERTYPEINFO_ANCILLARYDATAENTRY._options = None
_PARAMETERINFO_ANCILLARYDATAENTRY._options = None
_COMMANDINFO_ANCILLARYDATAENTRY._options = None
_CONTAINERINFO_ANCILLARYDATAENTRY._options = None
_CONTAINERINFO.fields_by_name['restrictionCriteria']._options = None
_LISTPARAMETERSRESPONSE.fields_by_name['spaceSystems']._options = None
_LISTCONTAINERSRESPONSE.fields_by_name['spaceSystems']._options = None
_LISTPARAMETERTYPESRESPONSE.fields_by_name['spaceSystems']._options = None
_LISTCOMMANDSRESPONSE.fields_by_name['spaceSystems']._options = None
_LISTALGORITHMSRESPONSE.fields_by_name['spaceSystems']._options = None
_CREATEPARAMETERREQUEST_ALIASESENTRY._options = None
_CREATEPARAMETERTYPEREQUEST_ALIASESENTRY._options = None
_SPACESYSTEMINFO_ANCILLARYDATAENTRY._options = None

_MDBAPI = _descriptor.ServiceDescriptor(
  name='MdbApi',
  full_name='yamcs.protobuf.mdb.MdbApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\200\001\003MDB',
  serialized_start=16293,
  serialized_end=19167,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMissionDatabase',
    full_name='yamcs.protobuf.mdb.MdbApi.GetMissionDatabase',
    index=0,
    containing_service=None,
    input_type=_GETMISSIONDATABASEREQUEST,
    output_type=_MISSIONDATABASE,
    serialized_options=b'\212\222\003\025\n\023/api/mdb/{instance}',
  ),
  _descriptor.MethodDescriptor(
    name='ExportJavaMissionDatabase',
    full_name='yamcs.protobuf.mdb.MdbApi.ExportJavaMissionDatabase',
    index=1,
    containing_service=None,
    input_type=_EXPORTJAVAMISSIONDATABASEREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\003 \n\036/api/mdb/{instance}:exportJava',
  ),
  _descriptor.MethodDescriptor(
    name='ListSpaceSystems',
    full_name='yamcs.protobuf.mdb.MdbApi.ListSpaceSystems',
    index=2,
    containing_service=None,
    input_type=_LISTSPACESYSTEMSREQUEST,
    output_type=_LISTSPACESYSTEMSRESPONSE,
    serialized_options=b'\212\222\0031\n!/api/mdb/{instance}/space-systemsR\014spaceSystems',
  ),
  _descriptor.MethodDescriptor(
    name='GetSpaceSystem',
    full_name='yamcs.protobuf.mdb.MdbApi.GetSpaceSystem',
    index=3,
    containing_service=None,
    input_type=_GETSPACESYSTEMREQUEST,
    output_type=_SPACESYSTEMINFO,
    serialized_options=b'\212\222\003+\n)/api/mdb/{instance}/space-systems/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='ExportXtce',
    full_name='yamcs.protobuf.mdb.MdbApi.ExportXtce',
    index=4,
    containing_service=None,
    input_type=_EXPORTXTCEREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\0036\n4/api/mdb/{instance}/space-systems/{name*}:exportXTCE',
  ),
  _descriptor.MethodDescriptor(
    name='StreamMissionDatabase',
    full_name='yamcs.protobuf.mdb.MdbApi.StreamMissionDatabase',
    index=5,
    containing_service=None,
    input_type=_STREAMMISSIONDATABASEREQUEST,
    output_type=_MISSIONDATABASEITEM,
    serialized_options=b'\212\222\003-\n)/api/mdb/{instance}:streamMissionDatabaseH\001',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameters',
    full_name='yamcs.protobuf.mdb.MdbApi.ListParameters',
    index=6,
    containing_service=None,
    input_type=_LISTPARAMETERSREQUEST,
    output_type=_LISTPARAMETERSRESPONSE,
    serialized_options=b'\212\222\003,\n\036/api/mdb/{instance}/parametersR\nparameters',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameter',
    full_name='yamcs.protobuf.mdb.MdbApi.GetParameter',
    index=7,
    containing_service=None,
    input_type=_GETPARAMETERREQUEST,
    output_type=_PARAMETERINFO,
    serialized_options=b'\212\222\003(\n&/api/mdb/{instance}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateParameter',
    full_name='yamcs.protobuf.mdb.MdbApi.CreateParameter',
    index=8,
    containing_service=None,
    input_type=_CREATEPARAMETERREQUEST,
    output_type=_PARAMETERINFO,
    serialized_options=b'\212\222\003#\032\036/api/mdb/{instance}/parameters:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetParameters',
    full_name='yamcs.protobuf.mdb.MdbApi.BatchGetParameters',
    index=9,
    containing_service=None,
    input_type=_BATCHGETPARAMETERSREQUEST,
    output_type=_BATCHGETPARAMETERSRESPONSE,
    serialized_options=b'\212\222\003,\032\'/api/mdb/{instance}/parameters:batchGet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterTypes',
    full_name='yamcs.protobuf.mdb.MdbApi.ListParameterTypes',
    index=10,
    containing_service=None,
    input_type=_LISTPARAMETERTYPESREQUEST,
    output_type=_LISTPARAMETERTYPESRESPONSE,
    serialized_options=b'\212\222\0035\n#/api/mdb/{instance}/parameter-typesR\016parameterTypes',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterType',
    full_name='yamcs.protobuf.mdb.MdbApi.GetParameterType',
    index=11,
    containing_service=None,
    input_type=_GETPARAMETERTYPEREQUEST,
    output_type=_PARAMETERTYPEINFO,
    serialized_options=b'\212\222\003-\n+/api/mdb/{instance}/parameter-types/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateParameterType',
    full_name='yamcs.protobuf.mdb.MdbApi.CreateParameterType',
    index=12,
    containing_service=None,
    input_type=_CREATEPARAMETERTYPEREQUEST,
    output_type=_PARAMETERTYPEINFO,
    serialized_options=b'\212\222\003(\032#/api/mdb/{instance}/parameter-types:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListContainers',
    full_name='yamcs.protobuf.mdb.MdbApi.ListContainers',
    index=13,
    containing_service=None,
    input_type=_LISTCONTAINERSREQUEST,
    output_type=_LISTCONTAINERSRESPONSE,
    serialized_options=b'\212\222\003,\n\036/api/mdb/{instance}/containersR\ncontainers',
  ),
  _descriptor.MethodDescriptor(
    name='GetContainer',
    full_name='yamcs.protobuf.mdb.MdbApi.GetContainer',
    index=14,
    containing_service=None,
    input_type=_GETCONTAINERREQUEST,
    output_type=_CONTAINERINFO,
    serialized_options=b'\212\222\003(\n&/api/mdb/{instance}/containers/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='ListCommands',
    full_name='yamcs.protobuf.mdb.MdbApi.ListCommands',
    index=15,
    containing_service=None,
    input_type=_LISTCOMMANDSREQUEST,
    output_type=_LISTCOMMANDSRESPONSE,
    serialized_options=b'\212\222\003(\n\034/api/mdb/{instance}/commandsR\010commands',
  ),
  _descriptor.MethodDescriptor(
    name='GetCommand',
    full_name='yamcs.protobuf.mdb.MdbApi.GetCommand',
    index=16,
    containing_service=None,
    input_type=_GETCOMMANDREQUEST,
    output_type=_COMMANDINFO,
    serialized_options=b'\212\222\003&\n$/api/mdb/{instance}/commands/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='ListAlgorithms',
    full_name='yamcs.protobuf.mdb.MdbApi.ListAlgorithms',
    index=17,
    containing_service=None,
    input_type=_LISTALGORITHMSREQUEST,
    output_type=_LISTALGORITHMSRESPONSE,
    serialized_options=b'\212\222\003,\n\036/api/mdb/{instance}/algorithmsR\nalgorithms',
  ),
  _descriptor.MethodDescriptor(
    name='GetAlgorithm',
    full_name='yamcs.protobuf.mdb.MdbApi.GetAlgorithm',
    index=18,
    containing_service=None,
    input_type=_GETALGORITHMREQUEST,
    output_type=_ALGORITHMINFO,
    serialized_options=b'\212\222\003(\n&/api/mdb/{instance}/algorithms/{name*}',
  ),
])
_sym_db.RegisterServiceDescriptor(_MDBAPI)

DESCRIPTOR.services_by_name['MdbApi'] = _MDBAPI

# @@protoc_insertion_point(module_scope)
